@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-audio-cd-composition-dialog.c 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  *  Copyright (c) 2005-2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -84,7 +83,7 @@ static void cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gin
 static XfceTitledDialogClass *parent_class = NULL;
 
 GType
-xfburn_burn_audio_cd_composition_dialog_get_type ()
+xfburn_burn_audio_cd_composition_dialog_get_type (void)
 {
   static GType type = 0;
 
@@ -153,11 +152,12 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
   g_object_unref (icon);
 
   /* burning devices list */
-  priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_SPEED_SELECTION | ACCEPT_ONLY_CD);
+  priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS |
+                                            SHOW_SPEED_SELECTION | SHOW_MODE_SELECTION |ACCEPT_ONLY_CD);
   g_signal_connect (G_OBJECT (priv->device_box), "volume-changed", G_CALLBACK (cb_volume_changed), obj);
   gtk_widget_show (priv->device_box);
 
-  priv->frame_device = xfce_create_framebox_with_content (_("Burning device"), priv->device_box);
+  priv->frame_device = xfce_gtk_frame_box_new_with_content (_("Burning device"), priv->device_box);
   gtk_widget_show (priv->frame_device);
   gtk_box_pack_start (box, priv->frame_device, FALSE, FALSE, BORDER);
 
@@ -169,7 +169,7 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
-    frame = xfce_create_framebox_with_content (_("Composition name"), vbox);
+    frame = xfce_gtk_frame_box_new_with_content (_("Composition name"), vbox);
     gtk_widget_show (frame);
     gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -191,7 +191,7 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox);
 
-  frame = xfce_create_framebox_with_content (_("Options"), vbox);
+  frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -219,7 +219,7 @@ xfburn_burn_audio_cd_composition_dialog_constructor (GType type, guint n_constru
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->button_proceed = button = xfce_create_mixed_button ("xfburn-burn-cd", _("_Burn Composition"));
+  priv->button_proceed = button = xfce_gtk_button_new_mixed ("xfburn-burn-cd", _("_Burn Composition"));
 
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
@@ -321,36 +321,19 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   burn_options = burn_write_opts_new (drive);
   burn_write_opts_set_perform_opc (burn_options, 0);
   burn_write_opts_set_multi (burn_options, 0);
-
-  /* keep all modes here, just in case we want to change the default sometimes */
-  switch (params->write_mode) {
-  case WRITE_MODE_TAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_TAO, BURN_BLOCK_MODE1);
-    break;
-  case WRITE_MODE_SAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_SAO, BURN_BLOCK_SAO);
-    break;
-  case WRITE_MODE_RAW16:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW16);
-    break;
-  case WRITE_MODE_RAW96P:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96P);
-    break;
-  case WRITE_MODE_RAW96R:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96R);
-    break;
-  default:
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
-    return;
-  }
-
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
-  DBG ("Set speed to %d kb/s", params->speed);
-  burn_drive_set_speed (drive, 0, params->speed);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
-  burn_drive_set_buffer_waiting (drive, 1, -1, -1, -1, 75, 95);
 
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, AUDIO_BYTES_PER_SECTOR, disc, srcs, track_sectors);
+  if (!xfburn_set_write_mode (burn_options, params->write_mode, disc, WRITE_MODE_SAO)) {
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
+  } else {
+
+    DBG ("Set speed to %d kb/s", params->speed);
+    burn_drive_set_speed (drive, 0, params->speed);
+    burn_drive_set_buffer_waiting (drive, 1, -1, -1, -1, 75, 95);
+
+    xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, AUDIO_BYTES_PER_SECTOR, disc, srcs, track_sectors);
+  }
 
   burn_write_opts_free (burn_options);
 }
@@ -368,7 +351,7 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
   int i,j;
   GSList *track_list;
   int *track_sectors;
-  gboolean abort = FALSE;
+  gboolean abort_burn = FALSE;
   XfburnTranscoder *trans;
   GError *error = NULL;
 
@@ -391,7 +374,7 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
     if (tracks[i] == NULL) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), error->message);
       g_error_free (error);
-      abort = TRUE;
+      abort_burn = TRUE;
       break;
     }
     srcs[i] = atrack->src;
@@ -401,15 +384,15 @@ thread_burn_composition (ThreadBurnCompositionParams * params)
     track_list = g_slist_next (track_list);
   }
 
-  if (!abort) {
+  if (!abort_burn) {
     if (!xfburn_transcoder_prepare (trans, &error)) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), error->message);
       g_error_free (error);
-      abort = TRUE;
+      abort_burn = TRUE;
     }
   }
 
-  if (!abort) {
+  if (!abort_burn) {
     if (!xfburn_device_grab (params->device, &drive_info)) {
       xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
     } else {
@@ -442,6 +425,12 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
   if (response_id == GTK_RESPONSE_OK) {
     GtkWidget *dialog_progress;
 
+    ThreadBurnCompositionParams *params = NULL;
+    XfburnDevice *device;
+    gint speed;
+    XfburnWriteMode write_mode;
+    //struct burn_source * src_fifo = NULL;
+
     /* If the name was the default, update the image volume id and volset id */
     /*
     if (priv->entry != NULL) {
@@ -457,16 +446,10 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
     
     gtk_widget_show (dialog_progress);
 
-    ThreadBurnCompositionParams *params = NULL;
-    XfburnDevice *device;
-    gint speed;
-    XfburnWriteMode write_mode;
-    //struct burn_source * src_fifo = NULL;
-
     device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
     speed = xfburn_device_box_get_speed (XFBURN_DEVICE_BOX (priv->device_box));
-    /* cdrskin burns audio with SAO */
-    write_mode = WRITE_MODE_SAO;
+    /* cdrskin burns audio with SAO, but we assume auto knows that */
+    write_mode = WRITE_MODE_AUTO;
 
     /* burn composition */
     params = g_new0 (ThreadBurnCompositionParams, 1);
@@ -478,7 +461,7 @@ cb_dialog_response (XfburnBurnAudioCdCompositionDialog * dialog, gint response_i
     params->eject = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_eject));
     params->dummy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_dummy));
     params->burnfree = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_burnfree));
-    g_thread_create ((GThreadFunc) thread_burn_composition, params, FALSE, NULL);
+    g_thread_new ("audio_cd_burn", (GThreadFunc) thread_burn_composition, params);
   }
 }
 
