@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-data-composition-base-dialog.c 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  *  Copyright (c) 2005-2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -67,11 +66,14 @@ typedef struct
   */
 
   gint response;
+
+  gboolean show_volume_name;
 } XfburnBurnDataCompositionBaseDialogPrivate;
 
 enum {
   PROP_0,
-  PROP_IMAGE
+  PROP_IMAGE,
+  PROP_SHOW_VOLUME_NAME,
 };
 
 /*
@@ -111,7 +113,7 @@ static void cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gi
 static XfceTitledDialogClass *parent_class = NULL;
 
 GType
-xfburn_burn_data_composition_base_dialog_get_type ()
+xfburn_burn_data_composition_base_dialog_get_type (void)
 {
   static GType type = 0;
 
@@ -150,7 +152,9 @@ xfburn_burn_data_composition_base_dialog_class_init (XfburnBurnDataCompositionBa
 
   /* properties */
   g_object_class_install_property (object_class, PROP_IMAGE,
-				   g_param_spec_pointer ("image", "Image", "Image", G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+				   g_param_spec_pointer ("image", _("Image"), _("Image"), G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
+  g_object_class_install_property (object_class, PROP_SHOW_VOLUME_NAME,
+				   g_param_spec_boolean ("show-volume-name", _("Show volume name"), _("Show a text entry for the name of the volume"), FALSE, G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
 }
 
 static GObject *
@@ -188,18 +192,18 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
 
   g_signal_connect (G_OBJECT (priv->device_box), "volume-changed", G_CALLBACK (cb_volume_changed), obj);
 
-  priv->frame_device = xfce_create_framebox_with_content (_("Burning device"), priv->device_box);
+  priv->frame_device = xfce_gtk_frame_box_new_with_content (_("Burning device"), priv->device_box);
   gtk_widget_show (priv->frame_device);
   gtk_box_pack_start (box, priv->frame_device, FALSE, FALSE, BORDER);
 
   /* composition name */
   comp_name = iso_image_get_volume_id (priv->image);
-  if (strcmp (comp_name, _(DATA_COMPOSITION_DEFAULT_NAME)) == 0) {
+  if (priv->show_volume_name) {
     GtkWidget *label;
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
-    frame = xfce_create_framebox_with_content (_("Composition name"), vbox);
+    frame = xfce_gtk_frame_box_new_with_content (_("Composition name"), vbox);
     gtk_widget_show (frame);
     gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -220,7 +224,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox);
 
-  frame = xfce_create_framebox_with_content (_("Options"), vbox);
+  frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -276,7 +280,7 @@ xfburn_burn_data_composition_base_dialog_constructor (GType type, guint n_constr
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->button_proceed = button = xfce_create_mixed_button ("xfburn-burn-cd", _("_Burn Composition"));
+  priv->button_proceed = button = xfce_gtk_button_new_mixed ("xfburn-burn-cd", _("_Burn Composition"));
   /*
    * Disabled: change button_proceed functionality
   button = create_proceed_button (obj, "xfburn-burn-cd", "");
@@ -305,6 +309,9 @@ xfburn_burn_data_composition_base_dialog_get_property (GObject * object, guint p
   case PROP_IMAGE:
     g_value_set_pointer (value, priv->image);
     break;
+  case PROP_SHOW_VOLUME_NAME:
+    g_value_set_boolean (value, priv->show_volume_name);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -320,6 +327,9 @@ xfburn_burn_data_composition_base_dialog_set_property (GObject * object, guint p
   case PROP_IMAGE:
     priv->image = g_value_get_pointer (value);
     break;
+  case PROP_SHOW_VOLUME_NAME:
+    priv->show_volume_name = g_value_get_boolean (value);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -490,8 +500,8 @@ thread_write_iso (ThreadWriteIsoParams * params)
       i++;
 
       if (i >= 1000) {
-	i = 0;
 	gdouble percent = 0;
+	i = 0;
 
 	percent = ((gdouble) written / (gdouble) size);
 
@@ -550,48 +560,32 @@ thread_burn_prep_and_burn (ThreadBurnCompositionParams * params, struct burn_dri
   burn_options = burn_write_opts_new (drive);
   burn_write_opts_set_perform_opc (burn_options, 0);
   burn_write_opts_set_multi (burn_options, 0);
-
-  switch (params->write_mode) {
-  case WRITE_MODE_TAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_TAO, BURN_BLOCK_MODE1);
-    break;
-  case WRITE_MODE_SAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_SAO, BURN_BLOCK_SAO);
-    break;
-  case WRITE_MODE_RAW16:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW16);
-    break;
-  case WRITE_MODE_RAW96P:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96P);
-    break;
-  case WRITE_MODE_RAW96R:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96R);
-    break;
-  default:
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
-    return;
-  }
-
   /* enable this when there is some time for testing
   DBG ("Enabling multisession");
   burn_write_opts_set_multi(burn_options, 1);
   */
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
-  DBG ("Set speed to %d kb/s", params->speed);
-  burn_drive_set_speed (drive, 0, params->speed);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
 
-  sectors[0] = burn_disc_get_sectors (disc);
+  if (!xfburn_set_write_mode (burn_options, params->write_mode, disc, WRITE_MODE_TAO)) {
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("The write mode is not supported currently."));
+  } else {
 
-  if (params->is_fifo) {
-    fifos = g_new(struct burn_source *,1);
-    fifos[0] = params->src;
-  }
+    DBG ("Set speed to %d kb/s", params->speed);
+    burn_drive_set_speed (drive, 0, params->speed);
 
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, DATA_BYTES_PER_SECTOR, disc, fifos, sectors);
+    sectors[0] = burn_disc_get_sectors (disc);
 
-  if (params->is_fifo) {
-    g_free (fifos);
+    if (params->is_fifo) {
+      fifos = g_new(struct burn_source *,1);
+      fifos[0] = params->src;
+    }
+
+    xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, DATA_BYTES_PER_SECTOR, disc, fifos, sectors);
+
+    if (params->is_fifo) {
+      g_free (fifos);
+    }
   }
 
   burn_write_opts_free (burn_options);
@@ -656,7 +650,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
 
     if (iso_image_create_burn_source (priv->image, write_opts, &src) < 0) {
       /* could not create source */
-      xfce_err (_("Could not create ISO source structure."));
+      xfce_dialog_show_error (NULL, NULL, _("Could not create ISO source structure."));
       return;
     }
 
@@ -677,7 +671,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
       params->dialog_progress = dialog_progress;
       params->src = src;
       params->iso_path = g_strdup (gtk_entry_get_text (GTK_ENTRY (priv->entry_path_iso)));
-      g_thread_create ((GThreadFunc) thread_write_iso, params, FALSE, NULL);
+      g_thread_new ("burn_iso", (GThreadFunc) thread_write_iso, params);
     }
     else {
       ThreadBurnCompositionParams *params = NULL;
@@ -704,7 +698,7 @@ cb_dialog_response (XfburnBurnDataCompositionBaseDialog * dialog, gint response_
       params->eject = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_eject));
       params->dummy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_dummy));
       params->burnfree = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_burnfree));
-      g_thread_create ((GThreadFunc) thread_burn_composition, params, FALSE, NULL);
+      g_thread_new ("burn_composition", (GThreadFunc) thread_burn_composition, params);
     }
   }
 }
