@@ -1,4 +1,3 @@
-/* $Id: xfburn-burn-image-dialog.c 6048 2008-11-10 05:36:10Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (squisher@xfce.org)
@@ -51,6 +50,14 @@ typedef struct {
   gboolean eject;
   gboolean dummy;
   gboolean burnfree;
+  gboolean quit;
+
+  struct burn_disc *disc;
+  struct burn_session *session;
+  struct burn_track *track;
+  struct burn_source *fifo_src;
+  struct burn_write_opts * burn_options;
+
 } ThreadBurnIsoParams;
 
 typedef struct
@@ -62,36 +69,49 @@ typedef struct
 
   GtkWidget *check_eject;
   GtkWidget *check_burnfree;
+  GtkWidget *check_quit;
   GtkWidget *check_dummy;
 
   GtkWidget *burn_button;
 
+  XfburnDeviceList *devlist;
+  gulong handler_volchange;
+
   ThreadBurnIsoParams *params;
+
 } XfburnBurnImageDialogPrivate;
 
+static gchar * last_file = NULL;
+
 /* prototypes */
 static void xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * klass);
 static void xfburn_burn_image_dialog_init (XfburnBurnImageDialog * sp);
+static void xfburn_burn_image_dialog_finalize (GObject *object);
 
+/* internal prototypes */
 void burn_image_dialog_error (XfburnBurnImageDialog * dialog, const gchar * msg_error);
-static void cb_device_changed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog);
-static void cb_disc_refreshed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog);
+static void cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, XfburnDevice *device, XfburnBurnImageDialog * dialog);
 static void cb_dialog_response (XfburnBurnImageDialog * dialog, gint response_id, gpointer user_data);
 
 static void update_image_label (GtkFileChooser *chooser, XfburnBurnImageDialog * dialog);
 static void check_burn_button (XfburnBurnImageDialog * dialog);
-static gboolean check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct burn_drive *drive, struct burn_write_opts * burn_options);
+static gboolean check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct burn_drive *drive);
 static void cb_clicked_ok (GtkButton * button, gpointer user_data);
 
+static void free_params (ThreadBurnIsoParams *params);
+static gboolean prepare_params (ThreadBurnIsoParams *params, struct burn_drive *drive, gchar **failure_msg);
+static gboolean create_disc (ThreadBurnIsoParams *params, gchar **failure_msg);
+static void thread_burn_iso (ThreadBurnIsoParams * params);
+
 /*********************/
 /* class declaration */
 /*********************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_burn_image_dialog_get_type ()
+GType
+xfburn_burn_image_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -116,8 +136,13 @@ xfburn_burn_image_dialog_get_type ()
 static void
 xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
   g_type_class_add_private (klass, sizeof (XfburnBurnImageDialogPrivate));
+
   parent_class = g_type_class_peek_parent (klass);
+
+  object_class->finalize     = xfburn_burn_image_dialog_finalize;
 }
 
 static void
@@ -149,11 +174,15 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(priv->chooser_image), filter);
   filter = gtk_file_filter_new ();
   gtk_file_filter_set_name (filter, _("ISO images"));
-  gtk_file_filter_add_pattern (filter, "*.iso");
+  gtk_file_filter_add_pattern (filter, "*.[iI][sS][oO]");
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
   gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
 
-  frame = xfce_create_framebox_with_content (_("Image to burn"), priv->chooser_image);
+  if (last_file) {
+    gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (priv->chooser_image), last_file);
+  }
+
+  frame = xfce_gtk_frame_box_new_with_content (_("Image to burn"), priv->chooser_image);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
   
@@ -168,7 +197,7 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_DVD_WRITERS | SHOW_MODE_SELECTION | SHOW_SPEED_SELECTION);
   gtk_widget_show (priv->device_box);
   
-  frame = xfce_create_framebox_with_content (_("Burning device"), priv->device_box);
+  frame = xfce_gtk_frame_box_new_with_content (_("Burning device"), priv->device_box);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -176,7 +205,7 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox);
 
-  frame = xfce_create_framebox_with_content (_("Options"), vbox);
+  frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
@@ -194,12 +223,17 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_widget_show (priv->check_burnfree);
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_burnfree, FALSE, FALSE, BORDER);
 
+  priv->check_quit = gtk_check_button_new_with_mnemonic (_("_Quit after success"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_quit), xfburn_settings_get_boolean("quit_after_success", FALSE));
+  gtk_widget_show (priv->check_quit);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->check_quit, FALSE, FALSE, BORDER);
+
   /* action buttons */
   button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->burn_button = xfce_create_mixed_button ("xfburn-burn-cd", _("_Burn image"));
+  priv->burn_button = xfce_gtk_button_new_mixed ("xfburn-burn-cd", _("_Burn image"));
   gtk_widget_show (priv->burn_button);
   g_signal_connect (G_OBJECT (priv->burn_button), "clicked", G_CALLBACK (cb_clicked_ok), obj);
   gtk_container_add (GTK_CONTAINER( GTK_DIALOG(obj)->action_area), priv->burn_button);
@@ -208,92 +242,102 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_widget_grab_focus (priv->burn_button);
   gtk_widget_grab_default (priv->burn_button);
 
-  g_signal_connect (G_OBJECT (priv->device_box), "device-changed", G_CALLBACK (cb_device_changed), obj);
-  g_signal_connect (G_OBJECT (priv->device_box), "disc-refreshed", G_CALLBACK (cb_disc_refreshed), obj);
+  priv->devlist = xfburn_device_list_new ();
+
+  priv->handler_volchange = g_signal_connect (G_OBJECT (priv->devlist), "volume-change-end", G_CALLBACK (cb_volume_change_end), obj);
   g_signal_connect (G_OBJECT (obj), "response", G_CALLBACK (cb_dialog_response), obj);
-  cb_disc_refreshed (XFBURN_DEVICE_BOX (priv->device_box), xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
+  device = xfburn_device_list_get_current_device (priv->devlist);
+
+  cb_volume_change_end (priv->devlist, TRUE, device, obj);
 
-  device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
   if (device)
-    gtk_widget_set_sensitive (priv->check_dummy, device->dummy_write);
+    gtk_widget_set_sensitive (priv->check_dummy, xfburn_device_can_dummy_write (device));
+}
 
+static void
+xfburn_burn_image_dialog_finalize (GObject *object)
+{
+  XfburnBurnImageDialog *dialog = XFBURN_BURN_IMAGE_DIALOG (object);
+  XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (dialog);
+
+  g_signal_handler_disconnect (priv->devlist, priv->handler_volchange);
+  g_object_unref (priv->devlist);
+
+  G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 /*************/
 /* internals */
 /*************/
-static struct burn_write_opts * 
-make_burn_options(ThreadBurnIsoParams *params, struct burn_drive *drive) {
+static gboolean 
+prepare_params (ThreadBurnIsoParams *params, struct burn_drive *drive, gchar **failure_msg)
+{
   struct burn_write_opts * burn_options;
 
   burn_options = burn_write_opts_new (drive);
   burn_write_opts_set_perform_opc (burn_options, 0);
   burn_write_opts_set_multi (burn_options, 0);
-
-  switch (params->write_mode) {
-  case WRITE_MODE_TAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_TAO, BURN_BLOCK_MODE1);
-    break;
-  case WRITE_MODE_SAO:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_SAO, BURN_BLOCK_SAO);
-    break;
-  /*
-  case WRITE_MODE_RAW16:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW16);
-    break;
-  case WRITE_MODE_RAW96P:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96P);
-    break;
-  case WRITE_MODE_RAW96R:
-    burn_write_opts_set_write_type (burn_options, BURN_WRITE_RAW, BURN_BLOCK_RAW96R);
-    break;
-  */
-  default:
-    burn_write_opts_free (burn_options);
-    return NULL;
-  }
-
   burn_write_opts_set_simulate(burn_options, params->dummy ? 1 : 0);
   burn_write_opts_set_underrun_proof (burn_options, params->burnfree ? 1 : 0);
 
-  return burn_options;
+  if (!xfburn_set_write_mode (burn_options, params->write_mode, params->disc, WRITE_MODE_TAO)) {
+    burn_write_opts_free (burn_options);
+    *failure_msg = _("Burn mode is not currently implemented.");
+    return FALSE;
+  }
+
+  params->burn_options = burn_options;
+
+  params->disc = burn_disc_create ();
+  params->session = burn_session_create ();
+  params->track = burn_track_create ();
+
+  if (!create_disc (params, failure_msg)) {
+    return FALSE;
+  }
+
+  return TRUE;
 }
 
 static void
-thread_burn_iso (ThreadBurnIsoParams * params)
+free_params (ThreadBurnIsoParams *params)
 {
-  GtkWidget *dialog_progress = params->dialog_progress;
+  if (params->fifo_src)
+    burn_source_free (params->fifo_src);
 
-  struct burn_disc *disc;
-  struct burn_session *session;
-  struct burn_track *track;
+  if (params->burn_options)
+    burn_write_opts_free (params->burn_options);
 
+  if (params->track)
+    burn_track_free (params->track);
+
+  if (params->session)
+    burn_session_free (params->session);
+
+  if (params->disc)
+    burn_disc_free (params->disc);
+
+  g_free (params->iso_path);
+}
+
+static gboolean
+create_disc (ThreadBurnIsoParams *params, gchar **failure_msg)
+{
   gint fd;
   struct stat stbuf;
   off_t fixed_size = 0;
   struct burn_source *data_src;
-  struct burn_source *fifo_src;
-  int sectors[1];
-
-  struct burn_drive *drive;
-  struct burn_drive_info *drive_info = NULL;
-  struct burn_write_opts * burn_options;
-  struct burn_source **fifos = NULL;
 
   gint ret;
 
-  disc = burn_disc_create ();
-  session = burn_session_create ();
-  track = burn_track_create ();
-
-  ret = burn_disc_add_session (disc, session, BURN_POS_END);
+  ret = burn_disc_add_session (params->disc, params->session, BURN_POS_END);
   if (ret == 0) {
-    g_warning ("Unable to create disc object");
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend"));
-    goto end;
+    g_warning ("Unable to add session to the disc object");
+    *failure_msg = _("An error occurred in the burn backend");
+    return FALSE;
   }
 
-  burn_track_define_data (track, 0, 300*1024, 1, BURN_MODE1);
+  burn_track_define_data (params->track, 0, 300*1024, 1, BURN_MODE1);
 
   fd = open (params->iso_path, O_RDONLY);
   if (fd >= 0)
@@ -302,68 +346,65 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 	fixed_size = stbuf.st_size;
 
   if (fixed_size == 0) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to determine image size."));
-    goto end;
+    *failure_msg = _("Unable to determine image size.");
+    return FALSE;
   }
 
   data_src = burn_fd_source_new(fd, -1, fixed_size);
 
   if (data_src == NULL) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot open image."));
-    goto end;
+    *failure_msg = _("Cannot open image.");
+    return FALSE;
   }
 
-  fifo_src = burn_fifo_source_new (data_src, 2048, xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE) / 2, 0);
+  params->fifo_src = burn_fifo_source_new (data_src, 2048, xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE) / 2, 0);
   burn_source_free (data_src);
 
-  if (burn_track_set_source (track, fifo_src) != BURN_SOURCE_OK) {
+  if (burn_track_set_source (params->track, params->fifo_src) != BURN_SOURCE_OK) {
     g_warning ("Cannot attach source object to track object");
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend"));
-    goto end;
+    *failure_msg = _("An error occurred in the burn backend");
+    return FALSE;
   }
   
-  burn_session_add_track (session, track, BURN_POS_END);
+  burn_session_add_track (params->session, params->track, BURN_POS_END);
 
-  if (!xfburn_device_grab (params->device, &drive_info)) {
+  return TRUE;
+}
+
+static void
+thread_burn_iso (ThreadBurnIsoParams * params)
+{
+  GtkWidget *dialog_progress = params->dialog_progress;
+
+  struct burn_drive *drive;
+  struct burn_drive_info *drive_info = NULL;
+  struct burn_source **fifos = NULL;
+  int sectors[1];
+
+  if (xfburn_device_grab (params->device, &drive_info)) {
+    drive = drive_info->drive;
+
+    DBG ("Set speed to %d kb/s", params->speed);
+    burn_drive_set_speed (drive, 0, params->speed);
+
+    // this assumes that an iso image can only have one track
+    sectors[0] = burn_disc_get_sectors (params->disc);
+    
+    xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Burning image..."));
+
+    fifos = g_new(struct burn_source *,1);
+    fifos[0] = params->fifo_src;
+
+    xfburn_perform_burn_write (dialog_progress, drive_info->drive, params->write_mode, params->burn_options, DATA_BYTES_PER_SECTOR, params->disc, fifos, sectors);
+ 
+    xfburn_device_release (drive_info, params->eject);
+  } else {
     xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
-
-    goto end;
   }
 
-  drive = drive_info->drive;
-
-  burn_options = make_burn_options (params, drive);
-  if (burn_options == NULL) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Burn mode is not currently implemented."));
-    goto cleanup;
-  }
-
-  DBG ("Set speed to %d kb/s", params->speed);
-  burn_drive_set_speed (drive, 0, params->speed);
-
-  // this assumes that an iso image can only have one track
-  sectors[0] = burn_disc_get_sectors (disc);
-  
-  xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Burning image..."));
-
-  fifos = g_new(struct burn_source *,1);
-  fifos[0] = fifo_src;
-
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, DATA_BYTES_PER_SECTOR, disc, fifos, sectors);
-
   g_free (fifos);
 
-  burn_source_free (fifo_src);
-  burn_write_opts_free (burn_options);
-
- cleanup:
-  xfburn_device_release (drive_info, params->eject);
- end:
-  burn_track_free (track);
-  burn_session_free (session);
-  burn_disc_free (disc);
-
-  g_free (params->iso_path);
+  free_params (params);
   g_free (params);
 }
 
@@ -373,20 +414,16 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 void
 burn_image_dialog_error (XfburnBurnImageDialog * dialog, const gchar * msg_error)
 {
-  xfce_err (msg_error);
+  xfce_dialog_show_error (NULL, NULL, "%s", msg_error); 
 }
 
 static void
-cb_device_changed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog) 
+cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, XfburnDevice *device, XfburnBurnImageDialog * dialog)
 {
   XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (dialog);
 
-  gtk_widget_set_sensitive (priv->check_dummy, device->dummy_write);
-}
-
-static void
-cb_disc_refreshed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog) 
-{
+  if (device_changed)
+    gtk_widget_set_sensitive (priv->check_dummy, xfburn_device_can_dummy_write (device));
   check_burn_button (dialog);
 }
 
@@ -398,15 +435,21 @@ cb_dialog_response (XfburnBurnImageDialog * dialog, gint response_id, gpointer u
     XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (dialog);
 
     GtkWidget *dialog_progress;
+    gboolean quit;
 
     dialog_progress = xfburn_progress_dialog_new (GTK_WINDOW (dialog));
     gtk_window_set_transient_for (GTK_WINDOW (dialog_progress), gtk_window_get_transient_for (GTK_WINDOW (dialog)));
     gtk_widget_hide (GTK_WIDGET (dialog));
-    
+
+    quit = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(priv->check_quit));
+    xfburn_settings_set_boolean ("quit_after_success", quit);
+
+    g_object_set (G_OBJECT (dialog_progress), "quit", quit, NULL);
+
     priv->params->dialog_progress = dialog_progress;
     gtk_widget_show (dialog_progress);
     
-    g_thread_create ((GThreadFunc) thread_burn_iso, priv->params, FALSE, NULL);
+    g_thread_new ("burn_iso", (GThreadFunc) thread_burn_iso, priv->params);
   } else {
     xfburn_main_leave_window ();
   }
@@ -436,15 +479,17 @@ check_burn_button (XfburnBurnImageDialog * dialog)
   g_object_get (G_OBJECT (priv->device_box), "valid", &valid_disc, NULL);
   filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (priv->chooser_image));
   if (filename != NULL) {
+    if (last_file)
+        g_free (last_file);
+    last_file = filename;
     gtk_widget_set_sensitive (priv->burn_button, valid_disc);
-    g_free (filename);
   } else {
     gtk_widget_set_sensitive (priv->burn_button, FALSE);
   }
 }
 
 static gboolean 
-check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct burn_drive *drive, struct burn_write_opts * burn_options)
+check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct burn_drive *drive)
 {
   enum burn_disc_status disc_state;
   struct stat st;
@@ -475,7 +520,7 @@ check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct
   ret = stat (params->iso_path, &st);
   if (ret == 0) {
     off_t disc_size;
-    disc_size = burn_disc_available_space (drive, burn_options);
+    disc_size = burn_disc_available_space (drive, params->burn_options);
     if (st.st_size > disc_size) {
       burn_image_dialog_error (dialog, _("The selected image does not fit on the inserted disc"));
       return FALSE;
@@ -499,11 +544,12 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
   XfburnDevice *device;
   gint speed;
   XfburnWriteMode write_mode;
-  struct burn_write_opts * burn_options;
 
   ThreadBurnIsoParams *params = NULL;
   struct burn_drive_info *drive_info = NULL;
 
+  gchar *failure_msg;
+
   /* check if the image file really exists and can be opened */
   iso_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (priv->chooser_image));
 
@@ -536,32 +582,28 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
     return;
   }
 
-  burn_options = make_burn_options (params, drive_info->drive);
-
-  if (burn_options == NULL)
-    burn_image_dialog_error (dialog, _("The write mode is not currently supported"));
-  else {
-    checks_passed = check_media (dialog, params, drive_info->drive, burn_options);
-
-    burn_write_opts_free (burn_options);
+  if (!prepare_params(params, drive_info->drive, &failure_msg)) {
+    burn_image_dialog_error (dialog, failure_msg);
+  } else {
+    checks_passed = check_media (dialog, params, drive_info->drive);
   }
 
   xfburn_device_release (drive_info, 0);
 
-  priv->params = params;
 
-  if (checks_passed)
+  if (checks_passed) {
+    priv->params = params;
+
     gtk_dialog_response (GTK_DIALOG(dialog), GTK_RESPONSE_OK);
-  else {
-    g_free (params->iso_path);
+  } else {
+    free_params (params);
     g_free (params);
   }
 }
 
-
 /* public */
 GtkWidget *
-xfburn_burn_image_dialog_new ()
+xfburn_burn_image_dialog_new (void)
 {
   GtkWidget *obj;
 
