@@ -1,4 +1,3 @@
-/* $Id: xfburn-copy-cd-progress-dialog.c 6014 2008-11-08 05:06:17Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -42,10 +41,10 @@ static void cb_new_output (XfburnCopyCdProgressDialog * dialog, const gchar * ou
 /*********************/
 static XfburnProgressDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_copy_cd_progress_dialog_get_type ()
+GType
+xfburn_copy_cd_progress_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -149,7 +148,7 @@ cb_new_output (XfburnCopyCdProgressDialog * dialog, const gchar * output, gpoint
 /*        */
 
 GtkWidget *
-xfburn_copy_cd_progress_dialog_new ()
+xfburn_copy_cd_progress_dialog_new (void)
 {
   XfburnCopyCdProgressDialog *obj;
 
