@@ -35,11 +35,9 @@
 
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
-#ifdef HAVE_THUNAR_VFS
-#include <thunar-vfs/thunar-vfs.h>
-#endif
+#include <gio/gio.h>
 
 #include <exo/exo.h>
 
@@ -56,6 +54,7 @@
 #include "xfburn-data-disc-usage.h"
 #include "xfburn-main-window.h"
 #include "xfburn-utils.h"
+#include "xfburn-settings.h"
 
 #define XFBURN_DATA_COMPOSITION_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_DATA_COMPOSITION, XfburnDataCompositionPrivate))
 
@@ -118,7 +117,9 @@ static void action_create_directory (GtkAction *, XfburnDataComposition *);
 static void action_clear (GtkAction *, XfburnDataComposition *);
 static void action_remove_selection (GtkAction *, XfburnDataComposition *);
 static void action_rename_selection (GtkAction *, XfburnDataComposition *);
-static void action_add_selected_files (GtkAction *, XfburnDataComposition *);
+static void action_add_or_select (GtkAction *, XfburnDataComposition *);
+static void add_files (gchar * files, XfburnDataComposition *);
+static void add_cb (GtkWidget * widget, gpointer data);
 
 static gboolean cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, XfburnDataComposition * dc);
 static void cb_treeview_row_activated (GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * column, XfburnDataComposition * composition);
@@ -173,6 +174,8 @@ typedef struct
   GtkWidget *disc_usage;
   GtkWidget *progress;
   GtkTreeStore *model;
+  GtkWidget *add_filechooser;
+  GtkWidget *add_window;
 
   gchar *default_vol_name;
 
@@ -184,7 +187,7 @@ static guint instances = 0;
 
 static const GtkActionEntry action_entries[] = {
   {"add-file", GTK_STOCK_ADD, N_("Add"), NULL, N_("Add the selected file(s) to the composition"),
-   G_CALLBACK (action_add_selected_files),},
+   G_CALLBACK (action_add_or_select),},
   {"create-dir", GTK_STOCK_NEW, N_("Create directory"), NULL, N_("Add a new directory to the composition"),
    G_CALLBACK (action_create_directory),},
   {"remove-file", GTK_STOCK_REMOVE, N_("Remove"), NULL, N_("Remove the selected file(s) from the composition"),
@@ -288,9 +291,7 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
 
   GtkTargetEntry gte_src[] =  { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE } };
   GtkTargetEntry gte_dest[] = { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE },
-#ifdef HAVE_THUNAR_VFS
                                 { "text/uri-list", 0, DATA_COMPOSITION_DND_TARGET_TEXT_URI_LIST },
-#endif
                                 { "text/plain;charset=utf-8", 0, DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN },
                               };
 
@@ -675,7 +676,7 @@ cb_cell_file_edited (GtkCellRenderer * renderer, gchar * path, gchar * newtext,
   GtkTreePath *real_path;
 
   if (strlen (newtext) == 0) {
-    xfce_err (_("You must give a name to the file."));
+    xfce_dialog_show_error (NULL, NULL, _("You must give a name to the file."));
     return;
   }
     
@@ -684,7 +685,7 @@ cb_cell_file_edited (GtkCellRenderer * renderer, gchar * path, gchar * newtext,
 
   if (gtk_tree_model_get_iter (model, &iter, real_path)) {
     if (file_exists_on_same_level (model, real_path, TRUE, newtext)) {
-      xfce_err (_("A file with the same name is already present in the composition."));
+      xfce_dialog_show_error (NULL, NULL, _("A file with the same name is already present in the composition."));
     }
     else {
       gtk_tree_store_set (GTK_TREE_STORE (model), &iter, DATA_COMPOSITION_COLUMN_CONTENT, newtext, -1);
@@ -899,18 +900,92 @@ action_remove_selection (GtkAction * action, XfburnDataComposition * dc)
   g_list_free (references);
 }
 
+static void
+add_cb (GtkWidget * widget, gpointer data)
+{
+    XfburnDataComposition * dc = XFBURN_DATA_COMPOSITION(data);
+    XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (dc);
+    gchar *selected_files = NULL;
+  
+    GSList *list = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (priv->add_filechooser));
+    GString  * str = g_string_new(NULL);
+    GSList * curr;
+
+    for (curr = list; curr!=NULL; curr = curr->next) {
+        g_string_append(str, curr->data);
+        g_string_append_c(str, '\n');;
+    }
+
+    g_slist_free_full (list, g_free);
+    selected_files = str->str;
+    g_string_free (str, FALSE);
+    DBG("selected  files: %s ", selected_files);
+
+    gtk_widget_destroy (priv->add_window);
+
+    add_files (selected_files, dc);
+}
 
 static void
-action_add_selected_files (GtkAction *action, XfburnDataComposition *dc)
+select_files (XfburnDataComposition * dc)
+{
+    XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (dc);
+
+    GtkWidget * window;
+    GtkWidget * add_button;
+    GtkWidget * vbox;
+    GtkWidget * bbox;
+
+    priv->add_window = window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_DIALOG);
+    gtk_window_set_title (GTK_WINDOW(window), _("File(s) to add to composition"));
+    gtk_window_set_position (GTK_WINDOW(window), GTK_WIN_POS_CENTER); // GTK_WINDOW(xfburn_main_window_get_instance()),
+    gtk_container_set_border_width (GTK_CONTAINER(window), 10);
+    gtk_window_set_default_size(GTK_WINDOW(window), 600, 400);
+
+    priv->add_filechooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_OPEN);
+
+    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(priv->add_filechooser), TRUE);
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_container_add(GTK_CONTAINER(window), vbox);
+
+    gtk_box_pack_start(GTK_BOX(vbox), priv->add_filechooser, TRUE, TRUE, 3);
+
+    add_button = gtk_button_new_with_label (_("Add"));
+    g_signal_connect (add_button, "clicked", G_CALLBACK(add_cb), dc);
+    g_signal_connect (priv->add_filechooser, "file-activated", G_CALLBACK(add_cb), dc);
+
+    bbox = gtk_hbutton_box_new ();
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
+    gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 3);
+
+    gtk_box_pack_end(GTK_BOX(bbox), add_button, FALSE, FALSE, 3);
+
+    g_signal_connect(window, "destroy",
+                     G_CALLBACK(gtk_widget_destroyed), &window);
+
+    gtk_widget_show_all (window);
+}
+
+static void
+action_add_or_select (GtkAction *action, XfburnDataComposition *dc)
+{
+  if (xfburn_settings_get_boolean("show-filebrowser", FALSE)) {
+    XfburnFileBrowser *browser = xfburn_main_window_get_file_browser (xfburn_main_window_get_instance ());
+  
+    add_files (xfburn_file_browser_get_selection (browser), dc);
+  } else {
+    select_files(dc);
+  }
+}
+
+static void
+add_files(gchar * selected_files, XfburnDataComposition *dc)
 {
   XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (dc);
-  XfburnFileBrowser *browser = xfburn_main_window_get_file_browser (xfburn_main_window_get_instance ());
-  
-  gchar *selected_files = NULL;
-  
+
   xfburn_busy_cursor (priv->content);
-  selected_files = xfburn_file_browser_get_selection (browser);
-  
   if (selected_files) {
     GtkTreeSelection *selection;
     GList *selected_paths = NULL;
@@ -937,7 +1012,7 @@ action_add_selected_files (GtkAction *action, XfburnDataComposition *dc)
     priv->selected_files = selected_files;
 
     priv->thread_params = params;
-    g_thread_create ((GThreadFunc) thread_add_files_action, params, FALSE, NULL);
+    g_thread_new ("data_add_files", (GThreadFunc) thread_add_files_action, params);
     
     g_list_foreach (selected_paths, (GFunc) gtk_tree_path_free, NULL);
     g_list_free (selected_paths);
@@ -1035,6 +1110,7 @@ static void
 set_modified (XfburnDataCompositionPrivate *priv)
 {
   if (!(priv->modified)) {
+    /*
     XfburnMainWindow *mainwin;
     GtkUIManager *ui_manager;
     GtkActionGroup *action_group;
@@ -1044,10 +1120,9 @@ set_modified (XfburnDataCompositionPrivate *priv)
   
     action_group = (GtkActionGroup *) gtk_ui_manager_get_action_groups (ui_manager)->data;
     
-    /*
     action = gtk_action_group_get_action (action_group, "save-composition");
     gtk_action_set_sensitive (GTK_ACTION (action), TRUE);
-  */
+    */
     priv->modified = TRUE;
   }
 }
@@ -1075,7 +1150,9 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
     
     /* ensure that we can only drop on top of folders, not files */
     if (insertion) {
+      gdk_threads_enter ();
       gtk_tree_model_get (model, insertion, DATA_COMPOSITION_COLUMN_TYPE, &parent_type, -1);
+      gdk_threads_leave ();
 
       if (parent_type == DATA_COMPOSITION_TYPE_FILE) {
         DBG ("Parent is file, and we're dropping into %d", position);
@@ -1116,11 +1193,9 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
     } else {
       tree_path = gtk_tree_path_new_first ();
     }
-    gdk_threads_leave ();
     
-    gdk_threads_enter ();
     if (file_exists_on_same_level (model, tree_path, FALSE, name)) {
-      xfce_err (_("A file with the same name is already present in the composition."));
+      xfce_dialog_show_error (NULL, NULL, _("A file with the same name is already present in the composition."));
 
       gtk_tree_path_free (tree_path);
       gdk_threads_leave ();
@@ -1188,18 +1263,18 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
     }
     /* new file */
     else if (S_ISREG (s.st_mode) || S_ISCHR(s.st_mode) || S_ISBLK(s.st_mode) || S_ISLNK (s.st_mode)) {
-#ifdef HAVE_THUNAR_VFS
       GdkScreen *screen;
       GtkIconTheme *icon_theme;
-      ThunarVfsMimeDatabase *mime_database = NULL;
-      ThunarVfsMimeInfo *mime_info = NULL;
-      const gchar *mime_icon_name = NULL;
-      GdkPixbuf *mime_icon = NULL;
+      GdkPixbuf *mime_icon_pixbuf = NULL;
       gint x,y;
+      GFile *file = NULL;
+      GFileInfo *info = NULL;
+      GIcon *mime_icon = NULL;
+      GtkIconInfo *icon_info = NULL;
 
       if (s.st_size > MAXIMUM_ISO_FILE_SIZE) {
         gdk_threads_enter ();
-        xfce_err (_("%s cannot be added to the composition, because it exceeds the maximum allowed file size for iso9660."), path);
+        xfce_dialog_show_error (NULL, NULL, _("%s cannot be added to the composition, because it exceeds the maximum allowed file size for iso9660."), path);
         gdk_threads_leave ();
 
         return FALSE;
@@ -1208,45 +1283,38 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnDataComposition * dc
       gdk_threads_enter ();
       screen = gtk_widget_get_screen (GTK_WIDGET (dc));
       icon_theme = gtk_icon_theme_get_for_screen (screen);
-      
-      mime_database = thunar_vfs_mime_database_get_default ();
-      mime_info = thunar_vfs_mime_database_get_info_for_file (mime_database, path, NULL);
-          
       gtk_icon_size_lookup (GTK_ICON_SIZE_SMALL_TOOLBAR, &x, &y);
-      mime_icon_name = thunar_vfs_mime_info_lookup_icon_name (mime_info, icon_theme);
-      mime_icon = gtk_icon_theme_load_icon (icon_theme, mime_icon_name, x, 0, NULL);
-#endif
-	
+
+      file = g_file_new_for_path(path);
+      info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, G_FILE_QUERY_INFO_NONE, NULL, NULL);
+      mime_icon = g_content_type_get_icon (g_file_info_get_content_type (info));
+      if (mime_icon != NULL) {
+        icon_info = gtk_icon_theme_lookup_by_gicon (icon_theme, mime_icon, x, GTK_ICON_LOOKUP_USE_BUILTIN);
+        if (icon_info != NULL) {
+          mime_icon_pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+          gtk_icon_info_free (icon_info);
+        }
+      }
+
       gtk_tree_store_append (GTK_TREE_STORE (model), iter, parent);
 
       humansize = xfburn_humanreadable_filesize (s.st_size);
 
-#ifdef HAVE_THUNAR_VFS
       gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-                          DATA_COMPOSITION_COLUMN_ICON, (G_IS_OBJECT (mime_icon) ? mime_icon : icon_file),
+                          DATA_COMPOSITION_COLUMN_ICON, (G_IS_OBJECT (mime_icon_pixbuf) ? mime_icon_pixbuf : icon_file),
                           DATA_COMPOSITION_COLUMN_CONTENT, name,
                           DATA_COMPOSITION_COLUMN_HUMANSIZE, humansize,
                           DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size, 
                           DATA_COMPOSITION_COLUMN_PATH, path,
                           DATA_COMPOSITION_COLUMN_TYPE, DATA_COMPOSITION_TYPE_FILE, -1);
-#else
-      gtk_tree_store_set (GTK_TREE_STORE (model), iter,
-                          DATA_COMPOSITION_COLUMN_ICON, icon_file,
-                          DATA_COMPOSITION_COLUMN_CONTENT, name,
-                          DATA_COMPOSITION_COLUMN_HUMANSIZE, humansize,
-                          DATA_COMPOSITION_COLUMN_SIZE, (guint64) s.st_size,
-                          DATA_COMPOSITION_COLUMN_PATH, path,
-                          DATA_COMPOSITION_COLUMN_TYPE, DATA_COMPOSITION_TYPE_FILE, -1);
-#endif
 
       xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), s.st_size);
-#ifdef HAVE_THUNAR_VFS
+
       if (G_LIKELY (G_IS_OBJECT (mime_icon)))
         g_object_unref (mime_icon);
-      thunar_vfs_mime_info_unref (mime_info);
-      g_object_unref (mime_database);
+      if (G_LIKELY (G_IS_OBJECT (file)))
+        g_object_unref(file);
       gdk_threads_leave ();
-#endif
     }
     g_free (humansize);
     g_free (parent);
@@ -1459,7 +1527,7 @@ copy_entry_to (XfburnDataComposition *dc, GtkTreeIter *src, GtkTreeIter *dest, G
       }
     
       if (file_exists_on_same_level (model, path_level, FALSE, name)) {
-        xfce_warn (_("A file named \"%s\" already exists in this directory, the file hasn't been added."), name);
+	xfce_dialog_show_warning(NULL, NULL, _("A file named \"%s\" already exists in this directory, the file hasn't been added."), name);
         goto cleanup;
       }
       
@@ -1673,26 +1741,6 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
       for (i=0; files[i] != NULL && files[i][0] != '\0'; i++) {
         gchar *full_path;
 
-#ifdef HAVE_THUNAR_VFS
-        ThunarVfsPath *vfs_path;
-        GError *vfs_error = NULL;
-
-        vfs_path = thunar_vfs_path_new (files[i], &vfs_error);
-
-        if (vfs_error) {
-          g_warning ("Failed to create vfs path for '%s': %s", files[i], vfs_error->message);
-          g_error_free (vfs_error);
-          continue;
-        }
-
-        if (thunar_vfs_path_get_scheme (vfs_path) != THUNAR_VFS_PATH_SCHEME_FILE)
-          continue;
-        full_path = thunar_vfs_path_dup_string (vfs_path);
-
-        thunar_vfs_path_unref (vfs_path);
-
-#else /* no thunar-vfs */
-
         if (g_str_has_prefix (files[i], "file://"))
           full_path = g_build_filename (&files[i][7], NULL);
         else if (g_str_has_prefix (files[i], "file:"))
@@ -1702,8 +1750,7 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
 
         if (full_path[strlen (full_path) - 1] == '\r')
           full_path[strlen (full_path) - 1] = '\0';
-#endif
-
+					
         DBG ("Adding path '%s'", full_path);
 
         /* remember path to add it later in another thread */
@@ -1725,32 +1772,50 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
       gtk_tree_store_append (GTK_TREE_STORE (model), &params->iter_dummy, NULL);
 
       priv->thread_params = params;
-      g_thread_create ((GThreadFunc) thread_add_files_drag, params, FALSE, NULL);
+      g_thread_new ("data_add_dnd_plain", (GThreadFunc) thread_add_files_drag, params);
     }
 
     gtk_drag_finish (dc, TRUE, FALSE, t);
   } 
   else if (sd->target == gdk_atom_intern ("text/uri-list", FALSE)) {
-#ifdef HAVE_THUNAR_VFS
     GList *vfs_paths = NULL;
     GList *vfs_path;
-    GError *error = NULL;
+    GList *lp;
     gchar *full_path;
+    gchar **uris;
+    gsize   n;
 
-    vfs_paths = thunar_vfs_path_list_from_string ((gchar *) sd->data, &error);
+    uris = g_uri_list_extract_uris ((gchar *) sd->data);
+
+    for (n = 0; uris != NULL && uris[n] != NULL; ++n)
+      vfs_paths = g_list_append (vfs_paths, g_file_new_for_uri (uris[n]));
+
+    g_strfreev (uris);
 
     if (G_LIKELY (vfs_paths != NULL)) {
       ThreadAddFilesDragParams *params;
       priv->full_paths_to_add = NULL;
       for (vfs_path = vfs_paths; vfs_path != NULL; vfs_path = g_list_next (vfs_path)) {
-        ThunarVfsPath *path = THUNAR_VFS_PATH (vfs_path->data);
-        if (thunar_vfs_path_get_scheme (path) != THUNAR_VFS_PATH_SCHEME_FILE)
+	GFile *path = vfs_path->data;
+	if (path == NULL)
           continue;
-        full_path = thunar_vfs_path_dup_string (path);
+	/* unable to handle non-local files */
+	if (G_UNLIKELY (!g_file_has_uri_scheme (path, "file"))) {
+            g_object_unref (path);
+	    continue;
+        }
+        full_path = g_file_get_path (path);
+        /* if there is no local path, use the URI (which always works) */
+        if (full_path == NULL)
+            full_path = g_file_get_uri (path);
+        /* release the location */
         g_debug ("adding uri path: %s", full_path);
         priv->full_paths_to_add = g_list_prepend (priv->full_paths_to_add, full_path);
       }
-      thunar_vfs_path_list_free (vfs_paths);
+
+      for (lp = vfs_paths; lp != NULL; lp = lp->next)
+        g_object_unref (lp->data);
+      g_list_free (vfs_paths);
 
       priv->full_paths_to_add = g_list_reverse (priv->full_paths_to_add);
       /* FIXME: path_where_insert is always NULL here */
@@ -1765,22 +1830,14 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
       gtk_tree_store_append (GTK_TREE_STORE (model), &params->iter_dummy, NULL);
 
       priv->thread_params = params;
-      g_thread_create ((GThreadFunc) thread_add_files_drag, params, FALSE, NULL);
+      g_thread_new ("data_add_dnd_uri", (GThreadFunc) thread_add_files_drag, params);
 
       gtk_drag_finish (dc, TRUE, FALSE, t);
     } else {
-      if (G_UNLIKELY (error != NULL))
-        g_warning ("text/uri-list drag failed because '%s'", error->message);
-      else
-        g_warning("There were no files in the uri list!");
+      g_warning("There were no files in the uri list!");
       gtk_drag_finish (dc, FALSE, FALSE, t);
       xfburn_default_cursor (priv->content);
     }
-#else
-    g_warning ("Receiving this type of drag and drop requires thunar-vfs support, sorry!");
-    gtk_drag_finish (dc, FALSE, FALSE, t);
-    xfburn_default_cursor (priv->content);
-#endif
   } 
   else {
     g_warning ("Trying to receive an unsupported drag target, this should not happen.");
@@ -1821,10 +1878,11 @@ thread_add_files_drag (ThreadAddFilesDragParams *params)
       
       if (thread_add_file_to_list (composition, model, full_path, &iter, &iter_where_insert, position)) {
         if (position == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE 
-            || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
+            || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER) {
           gdk_threads_enter ();
           gtk_tree_view_expand_row (GTK_TREE_VIEW (widget), priv->path_where_insert, FALSE);
           gdk_threads_leave ();
+        }
       }
       
     } else  {
@@ -1874,26 +1932,29 @@ fill_image_with_composition (GtkTreeModel *model, IsoImage *image, IsoDir * pare
           g_error ("Failed adding %s as a node to the image: code %X!", src, r);
       }
 
-      basename = g_path_get_basename (src);
-
-      /* check if the file has been renamed */
-      if (strcmp (basename, name) != 0) {
-        /* rename the iso_node */
-        r = iso_node_set_name (node, name);
-
-        if (r == 0) {
-          /* The first string is the renamed name, the second one the original name */
-          xfce_warn (_("Duplicate filename '%s' for '%s'"), name, src);
-
-          g_free (basename);
-          g_free (name);
-          g_free (src);
-
-          continue;
+      if (src != '\0') {
+        basename = g_path_get_basename (src);
+        
+        /* check if the file has been renamed */
+        if (strcmp (basename, name) != 0) {
+          /* rename the iso_node */
+          r = iso_node_set_name (node, name);
+  
+          if (r == 0) {
+            /* The first string is the renamed name, the second one the original name */
+            xfce_dialog_show_warning(NULL, NULL, _("Duplicate filename '%s' for '%s'"), name, src);
+  
+            g_free (basename);
+            g_free (name);
+            g_free (src);
+  
+            continue;
+          }
         }
+
+        g_free (basename);
       }
 
-      g_free (basename);
       g_free (name);
       g_free (src);
 
@@ -1941,6 +2002,7 @@ typedef struct
   GQueue *queue_iter;
 } LoadParserStruct;
 
+/*
 static gint
 _find_attribute (const gchar ** attribute_names, const gchar * attr)
 {
@@ -1953,12 +2015,15 @@ _find_attribute (const gchar ** attribute_names, const gchar * attr)
 
   return -1;
 }
+*/
 
 static void
 load_composition_start (GMarkupParseContext * context, const gchar * element_name,
                         const gchar ** attribute_names, const gchar ** attribute_values,
                         gpointer data, GError ** error)
 {
+  g_error ("This method needs to get fixed, and does not work right now!");
+/*
   LoadParserStruct * parserinfo = (LoadParserStruct *) data;
   XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (parserinfo->dc);
 
@@ -1980,11 +2045,8 @@ load_composition_start (GMarkupParseContext * context, const gchar * element_nam
       model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content));
       parent = g_queue_peek_head (parserinfo->queue_iter);
           
-      g_error ("This method needs to get fixed, and does not work right now!");
-      /*
       add_file_to_list_with_name (attribute_values[i], parserinfo->dc, model, attribute_values[j], &iter, 
                                   parent, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
-      */
     }
   } else if (!strcmp (element_name, "directory")) {
     int i, j;
@@ -1999,6 +2061,7 @@ load_composition_start (GMarkupParseContext * context, const gchar * element_nam
       //add_directory_to_list (attribute_values[i], parserinfo->dc, model, attribute_values[j], &iter, parent);    
     }
   }
+  */
 }
 
 static void
@@ -2206,7 +2269,7 @@ xfburn_data_composition_add_files (XfburnDataComposition *dc, GSList * filelist)
     xfburn_busy_cursor (priv->content);
 
     priv->thread_params = params;
-    g_thread_create ((GThreadFunc) thread_add_files_cli, params, FALSE, NULL);
+    g_thread_new ("data_add_files_cli", (GThreadFunc) thread_add_files_cli, params);
   }
 }
 
