@@ -1,4 +1,3 @@
-/* $Id: xfburn-device-box.h 6350 2008-12-21 02:25:44Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -45,9 +44,8 @@ typedef struct
 typedef struct
 {
   GtkVBoxClass parent_class;
-  
-  void (*device_changed) (XfburnDeviceBox *box, XfburnDevice *device);
-  void (*disc_refreshed) (XfburnDeviceBox *box, XfburnDevice *device);
+
+  void (*volume_changed) (XfburnDeviceBox *box, gboolean device_changed, XfburnDevice *device);
 } XfburnDeviceBoxClass;
 
 typedef enum
@@ -67,6 +65,7 @@ typedef enum
 
 typedef enum
 {
+  WRITE_MODE_AUTO,
   WRITE_MODE_TAO,
   WRITE_MODE_SAO,
   WRITE_MODE_RAW16,
@@ -75,11 +74,10 @@ typedef enum
   WRITE_MODE_PACKET,
 } XfburnWriteMode;
 
-GtkType xfburn_device_box_get_type (void);
+GType xfburn_device_box_get_type (void);
 
 GtkWidget *xfburn_device_box_new (XfburnDeviceBoxFlags);
 
-gchar *xfburn_device_box_get_selected (XfburnDeviceBox *box);
 XfburnDevice *xfburn_device_box_get_selected_device (XfburnDeviceBox *box);
 
 gint xfburn_device_box_get_speed (XfburnDeviceBox *box);
