@@ -1,4 +1,3 @@
-/* $Id: xfburn-main-window.c 5931 2008-11-03 06:14:41Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -23,7 +22,7 @@
 
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <exo/exo.h>
 
@@ -33,7 +32,6 @@
 #include "xfburn-file-browser.h"
 #include "xfburn-compositions-notebook.h"
 #include "xfburn-blank-dialog.h"
-//#include "xfburn-format-dvd-dialog.h"
 #include "xfburn-copy-cd-dialog.h"
 #include "xfburn-copy-dvd-dialog.h"
 #include "xfburn-burn-image-dialog.h"
@@ -42,6 +40,7 @@
 #include "xfburn-settings.h"
 #include "xfburn-main.h"
 #include "xfburn-stock.h"
+#include "xfburn-utils.h"
 
 #define XFBURN_MAIN_WINDOW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_MAIN_WINDOW, XfburnMainWindowPrivate))
 
@@ -88,7 +87,6 @@ static void action_blank (GtkAction *, XfburnMainWindow *);
 static void action_copy_cd (GtkAction *, XfburnMainWindow *);
 static void action_burn_image (GtkAction *, XfburnMainWindow *);
 
-//static void action_format_dvd (GtkAction *, XfburnMainWindow *);
 //static void action_copy_dvd (GtkAction *, XfburnMainWindow *);
 static void action_burn_dvd_image (GtkAction *, XfburnMainWindow *);
 
@@ -133,9 +131,7 @@ static const GtkActionEntry action_entries[] = {
   /*{"copy-audio", "xfburn-audio-copy", N_("Copy Audio CD"), NULL, N_("Copy Audio CD"),}, */
   {"burn-image", "xfburn-burn-cd", N_("Burn Image"), NULL, N_("Burn Image"),
    G_CALLBACK (action_burn_image),},
-/*  {"format-dvd", "xfburn-format-dvdrw", N_("Format DVD+RW"), NULL, N_("Format DVD+RW"),
-   G_CALLBACK (action_format_dvd),},
-  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
+/*  {"copy-dvd", "xfburn-data-copy", N_("Copy DVD"), NULL, N_("Copy DVD"),
    G_CALLBACK (action_copy_dvd),}, */
   {"burn-dvd", "xfburn-burn-image", N_("Burn DVD Image"), NULL, N_("Burn DVD Image"),
    G_CALLBACK (action_burn_dvd_image),},
@@ -158,7 +154,6 @@ static const gchar *toolbar_actions[] = {
   "copy-data",
   //"copy-audio",
   "burn-image",
-  //"format-dvd",
   "copy-dvd",
   "burn-dvd",
   "refresh",
@@ -171,10 +166,10 @@ static XfburnMainWindow *instance = NULL;
 /**************************/
 /* XfburnMainWindow class */
 /**************************/
-GtkType
+GType
 xfburn_main_window_get_type (void)
 {
-  static GtkType main_window_type = 0;
+  static GType main_window_type = 0;
 
   if (!main_window_type) {
     static const GTypeInfo main_window_info = {
@@ -228,7 +223,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   /* the window itself */
   gtk_window_set_position (GTK_WINDOW (mainwin), GTK_WIN_POS_CENTER_ON_PARENT);
   gtk_window_set_title (GTK_WINDOW (mainwin), "Xfburn");
-  gtk_window_set_icon_name (GTK_WINDOW (mainwin), GTK_STOCK_CDROM);
+  gtk_window_set_icon_name (GTK_WINDOW (mainwin), XFBURN_STOCK);
   gtk_window_resize (GTK_WINDOW (mainwin), xfburn_settings_get_int ("main-window-width", 850),
 		     xfburn_settings_get_int ("main-window-height", 700));
 
@@ -310,7 +305,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
 
   /* filebrowser */
   priv->file_browser = xfburn_file_browser_new ();
-  gtk_paned_add1 (GTK_PANED (priv->vpaned), priv->file_browser);
+  gtk_paned_pack1 (GTK_PANED (priv->vpaned), priv->file_browser, TRUE, FALSE);
   gtk_widget_show (priv->file_browser);
 
   gtk_paned_set_position (GTK_PANED (priv->file_browser), xfburn_settings_get_int ("hpaned-position", 250));
@@ -318,7 +313,7 @@ xfburn_main_window_init (XfburnMainWindow * mainwin)
   /* compositions notebook */
   priv->compositions_notebook = xfburn_compositions_notebook_new ();
   gtk_widget_show (priv->compositions_notebook);
-  gtk_paned_add2 (GTK_PANED (priv->vpaned), priv->compositions_notebook);
+  gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->compositions_notebook, TRUE, FALSE);
   
   gtk_paned_set_position (GTK_PANED (priv->vpaned), xfburn_settings_get_int ("vpaned-position", 200));
 
@@ -409,19 +404,6 @@ action_burn_image (GtkAction * action, XfburnMainWindow * window)
   gtk_widget_destroy (dialog);
 }
 
-/*
-static void
-action_format_dvd (GtkAction * action, XfburnMainWindow * window)
-{
-  GtkWidget *dialog;
-  
-  dialog = xfburn_format_dvd_dialog_new ();
-  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
-}
-*/
-
 /*
 static void
 action_copy_dvd (GtkAction * action, XfburnMainWindow * window)
@@ -497,79 +479,69 @@ action_quit (GtkAction * action, XfburnMainWindow * window)
 static void
 action_about (GtkAction * action, XfburnMainWindow * window)
 {
-  XfceAboutInfo *info;
-  GtkWidget *dialog;
   gint x, y;
-  GdkPixbuf *icon;
-  guint n;
-
-  static const struct
-  {
-    gchar *name, *email, *language;
-  } translators[] = {
-    {"Mohamed Magdy", "mohamed.m.k@gmail.com", "ar",},
-    {"Pau Rul lan Ferragut", "paurullan@bulma.net", "ca",},
-    {"Michal Várady", "miko.vaji@gmail.com", "cs",},
-    {"Enrico Tröger", "enrico.troeger@uvena.de", "de",},
-    {"Fabian Nowak", "timstery@arcor.de", "de",},
-    {"Nico Schümann", "nico@prog.nico22.de", "de",},
-    {"Stavros Giannouris", "stavrosg2002@freemail.gr", "el",},
-    {"Jeff Bailes", "thepizzaking@gmail.com", "en_GB",},
-    {"Diego Rodriguez", "dieymir@yahoo.es", "es",},
-    {"Kristjan Siimson", "kristjan.siimson@gmail.com", "et",},
-    {"Piarres Beobide", "pi@beobide.net", "eu",},
-    {"Jari Rahkonen", "jari.rahkonen@pp1.inet.fi", "fi",},
-    {"Etienne Collet", "xanaxlnx@gmail.com", "fr",},
-    {"Maximilian Schleiss", "maximilian@xfce.org", "fr",},
-    {"Attila Szervác", "sas@321.hu", "hu",},
-    {"Daichi Kawahata", "daichi@xfce.org", "ja",},
-    {"ByungHyun Choi", "byunghyun.choi@debianusers.org", "kr",},
-    {"Mantas", "mantaz@users.sourceforge.net", "lt",},
-    {"Rihards Prieditis", "RPrieditis@inbox.lv", "lv",},
-    {"Terje Uriansrud", "ter@operamail.com", "nb_NO",},
-    {"Stephan Arts", "psybsd@gmail.com", "nl",},
-    {"Szymon Kałasz", "szymon_maestro@gazeta.pl", "pl",},
-    {"Fábio Nogueira", "deb-user-ba@ubuntu.com", "pt_BR",},
-    {"Og Maciel", "omaciel@xfce.org", "pt_BR",},
-    {"Nuno Miguel", "nunis@netcabo.pt", "pt_PT",},
-    {"Sergey Fedoseev", "fedoseev.sergey@gmail.com", "ru",},
-    {"Besnik Bleta", "besnik@programeshqip.org", "sq",},
-    {"Maxim V. Dziumanenko", "mvd@mylinux.com.ua", "uk",},
-    {"Dmitry Nikitin", "", "uk",},
-    {"ﻢﺤﻣﺩ ﻊﻠﻳ ﺎﻠﻤﻜﻳ", "makki.ma@gmail.com", "ur",},
-    {"正龙 赵", "longer.zhao@gmail.com", "zh_CN",},
-    {"Cosmo Chene", "cosmolax@gmail.com", "zh_TW",},
-  };
+  GdkPixbuf *icon = NULL;
+  const gchar *auth[] = { "David Mohr david@mcbf.net Author/Maintainer",
+	  		  "Mario Đanić mario@libburnia-project.org Author/Maintainer",
+			  "Jean-François Wauthy pollux@xfce.org Retired author/maintainer",
+			  NULL };
+  const gchar *translators =
+    "Mohamed Magdy mohamed.m.k@gmail.com ar\n"
+    "Pau Rul lan Ferragut paurullan@bulma.net ca\n"
+    "Michal Várady miko.vaji@gmail.com cs\n"
+    "Enrico Tröger enrico.troeger@uvena.de de\n"
+    "Fabian Nowak timstery@arcor.de de\n"
+    "Nico Schümann nico@prog.nico22.de de\n"
+    "Stavros Giannouris stavrosg2002@freemail.gr el\n"
+    "Jeff Bailes thepizzaking@gmail.com en_GB\n"
+    "Diego Rodriguez dieymir@yahoo.es es\n"
+    "Kristjan Siimson kristjan.siimson@gmail.com et\n"
+    "Piarres Beobide pi@beobide.net eu\n"
+    "Jari Rahkonen jari.rahkonen@pp1.inet.fi fi\n"
+    "Etienne Collet xanaxlnx@gmail.com fr\n"
+    "Maximilian Schleiss maximilian@xfce.org fr\n"
+    "Attila Szervác sas@321.hu hu\n"
+    "Daichi Kawahata daichi@xfce.org ja\n"
+    "ByungHyun Choi byunghyun.choi@debianusers.org kr\n"
+    "Mantas mantaz@users.sourceforge.net lt\n"
+    "Rihards Prieditis RPrieditis@inbox.lv lv\n"
+    "Terje Uriansrud ter@operamail.com nb_NO\n"
+    "Stephan Arts psybsd@gmail.com nl\n"
+    "Szymon Kałasz szymon_maestro@gazeta.pl pl\n"
+    "Fábio Nogueira deb-user-ba@ubuntu.com pt_BR\n"
+    "Og Maciel omaciel@xfce.org pt_BR\n"
+    "Nuno Miguel nunis@netcabo.pt pt_PT\n"
+    "Sergey Fedoseev fedoseev.sergey@gmail.com ru\n"
+    "Besnik Bleta besnik@programeshqip.org sq\n"
+    "Maxim V. Dziumanenko mvd@mylinux.com.ua uk\n"
+    "Dmitry Nikitin  uk\n"
+    "ﻢﺤﻣﺩ ﻊﻠﻳ ﺎﻠﻤﻜﻳ makki.ma@gmail.com ur\n"
+    "正龙 赵 longer.zhao@gmail.com zh_CN\n"
+    "Cosmo Chene cosmolax@gmail.com zh_TW\n";
 
   gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
-  icon = xfce_themed_icon_load ("media-optical", x);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = xfce_themed_icon_load ("media-cdrom", x);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-cdrom", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = xfce_themed_icon_load (GTK_STOCK_CDROM, x);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), GTK_STOCK_CDROM, x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
-  info = xfce_about_info_new ("Xfburn", VERSION, _("Another cd burning GUI"),
-                              XFCE_COPYRIGHT_TEXT ("2005-2008", "Jean-François Wauthy, David Mohr, Mario Đanić"), XFCE_LICENSE_GPL);
-  xfce_about_info_set_homepage (info, "http://www.xfce.org/projects/xfburn");
-  xfce_about_info_add_credit (info, "David Mohr", "david@mcbf.net", _("Author/Maintainer"));
-  xfce_about_info_add_credit (info, "Jean-François Wauthy", "pollux@xfce.org", _("Author/Maintainer"));
-  xfce_about_info_add_credit (info, "Mario Đanić", "mario@libburnia-project.org", _("Author/Maintainer"));
-  
+#if !GTK_CHECK_VERSION (2, 18, 0)
+  gtk_about_dialog_set_email_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
+  gtk_about_dialog_set_url_hook (exo_gtk_url_about_dialog_hook, NULL, NULL);
+#endif
+  gtk_show_about_dialog(GTK_WINDOW (window),
+		  "logo", icon,
+		  "program-name", "Xfburn",
+		  "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
+		  "version", VERSION,
+		  "comments", _("Another cd burning GUI"),
+		  "website", "http://www.xfce.org/projects/xfburn",
+		  "copyright", "2005-2008 David Mohr, Mario Đanić, Jean-François Wauthy",
+		  "authors", auth, 
+		  "translator-credits", translators,
+		  NULL);
 
-  for (n = 0; n < G_N_ELEMENTS (translators); ++n) {
-    gchar *s;
-
-    s = g_strdup_printf (_("Translator (%s)"), translators[n].language);
-    xfce_about_info_add_credit (info, translators[n].name, translators[n].email, s);
-    g_free (s);
-  }
-
-  dialog = xfce_about_dialog_new_with_values (GTK_WINDOW (window), info, icon);
-  gtk_widget_set_size_request (GTK_WIDGET (dialog), 400, 300);
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
-
-  xfce_about_info_free (info);
   if (G_LIKELY (icon != NULL))
     g_object_unref (G_OBJECT (icon));
 }
@@ -644,27 +616,35 @@ xfburn_main_window_new (void)
     XfburnMainWindowPrivate *priv;
     GtkAction *action;
     GList *device = NULL;
+    XfburnDeviceList *devlist;
     
     instance = win = XFBURN_MAIN_WINDOW (obj);
     priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (win);
 
     /* load settings */
     action = gtk_action_group_get_action (priv->action_group, "show-filebrowser");
-    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-filebrowser", TRUE));
+    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-filebrowser", FALSE));
     action = gtk_action_group_get_action (priv->action_group, "show-toolbar");
-    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-toolbar", TRUE));
+    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), xfburn_settings_get_boolean ("show-toolbar", FALSE));
    /* action = gtk_action_group_get_action (priv->action_group, "save-composition");
     gtk_action_set_sensitive (GTK_ACTION (action), FALSE);*/
 
     /* disable action that cannot be used due to device */
-    device = xfburn_device_list_get_list ();
 
+    devlist = xfburn_device_list_new ();
+    g_object_get (G_OBJECT (devlist), "devices", &device, NULL);
+    g_object_unref (devlist);
+
+    /* FIXME: this is really outdated behavior. Needs to get rewritten */
     while (device != NULL) {
       XfburnDevice *device_info = (XfburnDevice *) device->data;
+      gboolean cdr, cdrw;
 
-      if (device_info->cdr)
+      g_object_get (G_OBJECT (device_info), "cdr", &cdr, "cdrw", &cdrw, NULL);
+
+      if (cdr)
 	priv->support_cdr = TRUE;
-      if (device_info->cdrw)
+      if (cdrw)
 	priv->support_cdrw = TRUE;
 
       device = g_list_next (device);
@@ -691,7 +671,7 @@ xfburn_main_window_new (void)
 }
 
 XfburnMainWindow *
-xfburn_main_window_get_instance ()
+xfburn_main_window_get_instance (void)
 {
   if (!instance)
     g_warning ("No existing instance of XfburnMainWindow");
@@ -720,9 +700,12 @@ xfburn_main_window_add_data_composition_with_files (XfburnMainWindow *window, in
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
+  GSList * filelist;
  
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_DATA_COMPOSITION);
-  xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filec, filenames);
+
+  filelist = xfburn_make_abosulet_file_list (filec, filenames);
+  xfburn_data_composition_add_files (XFBURN_DATA_COMPOSITION (comp), filelist);
 }
 
 void 
@@ -730,9 +713,11 @@ xfburn_main_window_add_audio_composition_with_files (XfburnMainWindow *window, i
 {
   XfburnMainWindowPrivate *priv = XFBURN_MAIN_WINDOW_GET_PRIVATE (window);
   XfburnComposition *comp;
+  GSList * filelist;
  
   comp = xfburn_compositions_notebook_add_composition (XFBURN_COMPOSITIONS_NOTEBOOK (priv->compositions_notebook), XFBURN_AUDIO_COMPOSITION);
-  xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filec, filenames);
+  filelist = xfburn_make_abosulet_file_list (filec, filenames);
+  xfburn_audio_composition_add_files (XFBURN_AUDIO_COMPOSITION (comp), filelist);
 }
 
 gboolean
