@@ -1,4 +1,3 @@
-/* $Id: xfburn-perform-burn.h 4503 2008-04-03 17:33:37Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  * Copyright (c) 2008 David Mohr (squisher@xfce.org)
@@ -26,13 +25,17 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libburn.h>
 
 #include "xfburn-device-box.h"
 
-void xfburn_perform_burn_write (GtkWidget *dialog_progress, struct burn_drive *drive, XfburnWriteMode write_mode, struct burn_write_opts *burn_options, 
-                                struct burn_disc *disc, struct burn_source *fifo, int *track_sectors);
+gboolean xfburn_set_write_mode (struct burn_write_opts *opts, XfburnWriteMode write_mode, struct burn_disc *disc,
+                                XfburnWriteMode fallback);
+
+void xfburn_perform_burn_write (GtkWidget *dialog_progress, 
+                                struct burn_drive *drive, XfburnWriteMode write_mode, struct burn_write_opts *burn_options, int sector_size,
+                                struct burn_disc *disc, struct burn_source **fifos, int *track_sectors);
 
 #endif /* __XFBURN_PERFORM_BURN_H__ */
