@@ -1,4 +1,3 @@
-/* $Id: xfburn-preferences-dialog.c 6079 2008-11-12 22:10:18Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -21,7 +20,7 @@
 #include <config.h>
 #endif /* !HAVE_CONFIG_H */
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <exo/exo.h>
 
 #include "xfburn-preferences-dialog.h"
@@ -45,7 +44,9 @@ typedef struct
 
   GtkWidget *treeview_devices;
   GtkWidget *button_scan;
+#if 0
   GtkWidget *check_empty_speed_list;
+#endif
   GtkWidget *scale_fifo;
 } XfburnPreferencesDialogPrivate;
 
@@ -56,6 +57,7 @@ static void xfburn_preferences_dialog_init (XfburnPreferencesDialog * sp);
 static void refresh_devices_list (XfburnPreferencesDialog * dialog);
 static void scan_button_clicked_cb (GtkWidget * button, gpointer user_data);
 static void xfburn_preferences_dialog_response_cb (XfburnPreferencesDialog * dialog, guint response_id, XfburnPreferencesDialogPrivate * priv);
+static void cb_show_hidden_clicked (GtkButton * Button, gpointer user_data);
 
 enum {
   SETTINGS_LIST_PIXBUF_COLUMN,
@@ -86,10 +88,10 @@ typedef struct
 /*********************************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_preferences_dialog_get_type ()
+GType
+xfburn_preferences_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -136,10 +138,11 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   GtkTreeViewColumn *column_name;
   GtkCellRenderer *cell_icon, *cell_name;
   GtkWidget *button_close;
-  gint index;
+  gint idx;
   
   gtk_window_set_title (GTK_WINDOW (obj), _("Preferences"));
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (obj), _("Tune how Xfburn behaves"));
+  gtk_window_set_default_size (GTK_WINDOW (obj), 775, 400);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
   gtk_window_set_icon_name (GTK_WINDOW (obj), GTK_STOCK_PREFERENCES);
   gtk_dialog_set_has_separator (GTK_DIALOG (obj), FALSE);
@@ -178,13 +181,13 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   /* general tab */
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-  index = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
+  idx = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
   gtk_widget_show (vbox);
 
   vbox2 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox2);
 
-  frame = xfce_create_framebox_with_content (_("Temporary directory"), vbox2);
+  frame = xfce_gtk_frame_box_new_with_content (_("Temporary directory"), vbox2);
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, BORDER);
   gtk_widget_show (frame);
 
@@ -199,13 +202,14 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   vbox2 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox2);
 
-  frame = xfce_create_framebox_with_content (_("File browser"), vbox2);
+  frame = xfce_gtk_frame_box_new_with_content (_("File browser"), vbox2);
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, BORDER);
   gtk_widget_show (frame);
 
   priv->check_show_hidden = gtk_check_button_new_with_mnemonic (_("Show _hidden files"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_show_hidden, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_show_hidden);
+  g_signal_connect (G_OBJECT (priv->check_show_hidden), "clicked", G_CALLBACK (cb_show_hidden_clicked), NULL);
 
   priv->check_show_human_readable = gtk_check_button_new_with_mnemonic (_("Show human_readable filesizes"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_show_human_readable, FALSE, FALSE, BORDER);
@@ -219,14 +223,14 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   gtk_list_store_set (icon_store, &iter,
                       SETTINGS_LIST_PIXBUF_COLUMN, icon,
                       SETTINGS_LIST_TEXT_COLUMN, _("General"),
-                      SETTINGS_LIST_INDEX_COLUMN, index,
+                      SETTINGS_LIST_INDEX_COLUMN, idx,
                       -1);
   g_object_unref (G_OBJECT (icon));
   
   /* devices tab */
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-  index = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
+  idx = gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), vbox, NULL);
   gtk_widget_show (vbox);
 
   label = gtk_label_new (_("Devices"));
@@ -238,7 +242,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   vbox2 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox2);
 
-  frame = xfce_create_framebox_with_content (_("Detected devices"), vbox2);
+  frame = xfce_gtk_frame_box_new_with_content (_("Detected devices"), vbox2);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, BORDER);
   gtk_widget_show (frame);
 
@@ -290,24 +294,24 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, BORDER);
   gtk_widget_show (hbox);
 
-  priv->button_scan = xfce_create_mixed_button (GTK_STOCK_CDROM, _("Sc_an for devices"));
+  priv->button_scan = xfce_gtk_button_new_mixed (GTK_STOCK_CDROM, _("Sc_an for devices"));
   gtk_box_pack_end (GTK_BOX (hbox), priv->button_scan, FALSE, FALSE, BORDER);
   g_signal_connect (G_OBJECT (priv->button_scan), "clicked", G_CALLBACK (scan_button_clicked_cb), obj);
   gtk_widget_show (priv->button_scan);
 
   gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
-  icon = xfce_themed_icon_load ("media-optical", x);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-optical", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = xfce_themed_icon_load ("media-cdrom", x);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "media-cdrom", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   if (!icon)
-    icon = xfce_themed_icon_load (GTK_STOCK_CDROM, x);
+    icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), GTK_STOCK_CDROM, x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
   
   gtk_list_store_append (icon_store, &iter);
   gtk_list_store_set (icon_store, &iter,
                       SETTINGS_LIST_PIXBUF_COLUMN, icon,
                       SETTINGS_LIST_TEXT_COLUMN, _("Devices"),
-                      SETTINGS_LIST_INDEX_COLUMN, index,
+                      SETTINGS_LIST_INDEX_COLUMN, idx,
                       -1);
   if (icon)
     g_object_unref (G_OBJECT (icon));
@@ -316,15 +320,17 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
 
 
   /* below the device list */
+#if 0
   priv->check_empty_speed_list = gtk_check_button_new_with_mnemonic (_("Show warning on _empty speed list"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_empty_speed_list, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_empty_speed_list);
+#endif
 
   /* fifo */
   vbox3 = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox3);
 
-  frame = xfce_create_framebox_with_content (_("FIFO buffer size (in kb)"), vbox3);
+  frame = xfce_gtk_frame_box_new_with_content (_("FIFO buffer size (in kb)"), vbox3);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, BORDER);
   gtk_widget_show (frame);
 
@@ -368,8 +374,10 @@ xfburn_preferences_dialog_load_settings (XfburnPreferencesDialog * dialog)
                                 xfburn_settings_get_boolean ("show-hidden-files", FALSE));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_show_human_readable),
                                 xfburn_settings_get_boolean ("human-readable-units", TRUE));
+#if 0
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_empty_speed_list),
                                 xfburn_settings_get_boolean ("show-empty-speed-list-notice", TRUE));
+#endif
   gtk_range_set_value (GTK_RANGE (priv->scale_fifo),
                                 (double) xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE));
 }
@@ -390,8 +398,10 @@ xfburn_preferences_dialog_save_settings (XfburnPreferencesDialog *dialog)
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_show_hidden)));
   xfburn_settings_set_boolean ("human-readable-units", 
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_show_human_readable)));
+#if 0
   xfburn_settings_set_boolean ("show-empty-speed-list-notice", 
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_empty_speed_list)));
+#endif
   xfburn_settings_set_int ("fifo-size", 
                                ((((int) gtk_range_get_value (GTK_RANGE (priv->scale_fifo)) / 32) * 32))); /* this should round to multiples of 1024 */
 }
@@ -402,25 +412,40 @@ refresh_devices_list (XfburnPreferencesDialog * dialog)
   XfburnPreferencesDialogPrivate *priv = XFBURN_PREFERENCES_DIALOG_GET_PRIVATE (dialog);
   GtkTreeModel *model;
   GList *device;
+  XfburnDeviceList *devlist;
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview_devices));
 
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
-  device = xfburn_device_list_get_list ();
+  devlist = xfburn_device_list_new ();
+  g_object_get (G_OBJECT (devlist), "devices", &device, NULL);
+  g_object_unref (devlist);
+
   while (device) {
     GtkTreeIter iter;
     XfburnDevice *device_data;
+    gchar *name, *addr;
+    gboolean cdr, cdrw, dvdr, dvdram;
 
     device_data = (XfburnDevice *) device->data;
 
+    g_object_get (G_OBJECT (device_data), "name", &name, "address", &addr,
+                  "cdr", &cdr, "cdrw", &cdrw, "dvdr", &dvdr, "dvdram", &dvdram,
+                  NULL);
+
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                        DEVICE_LIST_COLUMN_NAME, device_data->name,
-                        DEVICE_LIST_COLUMN_NODE, device_data->addr,
-                        DEVICE_LIST_COLUMN_CDR, device_data->cdr,
-                        DEVICE_LIST_COLUMN_CDRW, device_data->cdrw,
-                        DEVICE_LIST_COLUMN_DVDR, device_data->dvdr, DEVICE_LIST_COLUMN_DVDRAM, device_data->dvdram, -1);
+                        DEVICE_LIST_COLUMN_NAME, name,
+                        DEVICE_LIST_COLUMN_NODE, addr,
+                        DEVICE_LIST_COLUMN_CDR, cdr,
+                        DEVICE_LIST_COLUMN_CDRW, cdrw,
+                        DEVICE_LIST_COLUMN_DVDR, dvdr, 
+                        DEVICE_LIST_COLUMN_DVDRAM, dvdram, 
+                        -1);
+
+    g_free (name);
+    g_free (addr);
 
     device = g_list_next (device);
   }
@@ -437,13 +462,18 @@ xfburn_preferences_dialog_response_cb (XfburnPreferencesDialog * dialog, guint r
 static void
 scan_button_clicked_cb (GtkWidget * button, gpointer user_data)
 {
-  xfburn_device_list_init ();
   refresh_devices_list (user_data);
 }
 
+static void 
+cb_show_hidden_clicked (GtkButton * Button, gpointer user_data)
+{
+  xfce_dialog_show_warning(NULL, NULL, _("Changing this setting only takes full effect after a program restart."));
+}
+
 /* public */
 GtkWidget *
-xfburn_preferences_dialog_new ()
+xfburn_preferences_dialog_new (void)
 {
   GtkWidget *obj;
 
