@@ -1,4 +1,3 @@
-/* $Id: xfburn-progress-dialog.c 5403 2008-09-14 08:32:03Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -31,7 +30,7 @@
 
 #include <gtk/gtk.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "xfburn-progress-dialog.h"
 #include "xfburn-global.h"
@@ -39,6 +38,11 @@
 
 #define XFBURN_PROGRESS_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_PROGRESS_DIALOG, XfburnProgressDialogPrivate))
 
+enum {
+  BURNING_DONE,
+  LAST_SIGNAL,
+};
+
 /* struct */
 typedef struct
 {
@@ -46,6 +50,8 @@ typedef struct
   int fd_stdin;
   gboolean animate;
   int ani_index;
+  gboolean stop;
+  gboolean quit;
   
   GtkWidget *label_action;
   GtkWidget *progress_bar;
@@ -59,6 +65,8 @@ typedef struct
 } XfburnProgressDialogPrivate;
 
 /* globals */
+static guint signals[LAST_SIGNAL];
+
 static void xfburn_progress_dialog_class_init (XfburnProgressDialogClass * klass);
 static void xfburn_progress_dialog_init (XfburnProgressDialog * sp);
 
@@ -68,7 +76,9 @@ static void xfburn_progress_dialog_set_property (GObject * object, guint prop_id
 
 static void set_writing_speed (XfburnProgressDialog * dialog, gfloat speed);
 static void set_action_text (XfburnProgressDialog * dialog, XfburnProgressDialogStatus status, const gchar * text);
+static void stop (XfburnProgressDialog *dialog);
 
+static void cb_button_stop_clicked (GtkWidget *button, XfburnProgressDialog * dialog);
 static void cb_button_close_clicked (GtkWidget *button, XfburnProgressDialog * dialog);
 static gboolean cb_dialog_delete (XfburnProgressDialog * dialog, GdkEvent * event, XfburnProgressDialogPrivate * priv);
 
@@ -78,6 +88,8 @@ enum
   PROP_STATUS,
   PROP_SHOW_BUFFERS,
   PROP_ANIMATE,
+  PROP_QUIT,
+  PROP_STOP,
 };
 
 static gchar animation[] = { '-', '\\', '|', '/' };
@@ -107,10 +119,10 @@ xfburn_progress_dialog_status_get_type (void)
 /*                       */
 static GtkDialogClass *parent_class = NULL;
 
-GtkType
-xfburn_progress_dialog_get_type ()
+GType
+xfburn_progress_dialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -154,6 +166,17 @@ xfburn_progress_dialog_class_init (XfburnProgressDialogClass * klass)
   g_object_class_install_property (object_class, PROP_ANIMATE,
                                    g_param_spec_boolean ("animate", "Show an animation", "Show an animation",
                                                          FALSE, G_PARAM_READWRITE));
+  g_object_class_install_property (object_class, PROP_QUIT,
+                                   g_param_spec_boolean ("quit", "Quit", "Quit after successful completion",
+                                                         FALSE, G_PARAM_READWRITE));
+  g_object_class_install_property (object_class, PROP_STOP,
+                                   g_param_spec_boolean ("stop", "Stop the burning process", "Stop the burning process",
+                                                         FALSE, G_PARAM_READABLE));
+  /* signals */
+  signals[BURNING_DONE] = g_signal_new ("burning-done", XFBURN_TYPE_PROGRESS_DIALOG, G_SIGNAL_ACTION,
+                                          G_STRUCT_OFFSET (XfburnProgressDialogClass, burning_done),
+                                          NULL, NULL, g_cclosure_marshal_VOID__VOID,
+                                          G_TYPE_NONE, 0);
 }
 
 static void
@@ -225,6 +248,7 @@ xfburn_progress_dialog_init (XfburnProgressDialog * obj)
   priv->button_stop = gtk_button_new_from_stock (GTK_STOCK_STOP);
   gtk_widget_show (priv->button_stop);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), priv->button_stop, GTK_RESPONSE_CANCEL);
+  g_signal_connect (G_OBJECT (priv->button_stop), "clicked", G_CALLBACK (cb_button_stop_clicked), obj);
 
   priv->button_close = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
   gtk_widget_show (priv->button_close);
@@ -255,6 +279,12 @@ xfburn_progress_dialog_get_property (GObject * object, guint prop_id, GValue * v
   case PROP_ANIMATE:
     g_value_set_boolean (value, priv->animate);
     break;
+  case PROP_QUIT:
+    g_value_set_boolean (value, priv->quit);
+    break;
+  case PROP_STOP:
+    g_value_set_boolean (value, priv->stop);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -279,6 +309,13 @@ xfburn_progress_dialog_set_property (GObject * object, guint prop_id, const GVal
     priv->ani_index = 0;
     //DBG ("Set animate to %d", priv->animate);
     break;
+  case PROP_QUIT:
+    priv->quit = g_value_get_boolean (value);
+    break;
+  case PROP_STOP:
+    DBG ("this should not be allowed...");
+    priv->stop = g_value_get_boolean (value);
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     break;
@@ -317,7 +354,34 @@ set_action_text (XfburnProgressDialog * dialog, XfburnProgressDialogStatus statu
   g_free (temp);  
 }
 
+static void
+stop (XfburnProgressDialog *dialog)
+{
+  XfburnProgressDialogPrivate *priv = XFBURN_PROGRESS_DIALOG_GET_PRIVATE (dialog);
+
+  //DBG ("setting stop");
+  priv->stop = TRUE;
+}
+
 /* callbacks */
+static void
+cb_button_stop_clicked (GtkWidget *button, XfburnProgressDialog *dialog)
+{
+  gint res;
+  GtkWidget *popup;
+
+  popup = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
+                                  _("Are you sure you want to abort?"));
+
+  res = gtk_dialog_run (GTK_DIALOG (popup));
+  gtk_widget_destroy (popup);
+
+  if (res != GTK_RESPONSE_YES)
+    return;
+
+  stop (dialog);
+}
+
 static void
 cb_button_close_clicked (GtkWidget *button, XfburnProgressDialog *dialog)
 {
@@ -330,6 +394,8 @@ cb_dialog_delete (XfburnProgressDialog * dialog, GdkEvent * event, XfburnProgres
 {
   xfburn_main_leave_window ();
   if (!GTK_WIDGET_SENSITIVE (priv->button_close)) {
+    /* burn process is still ongoing, we need to stop first */
+    stop (dialog);
     gtk_dialog_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
     return TRUE;
   } else {
@@ -491,9 +557,15 @@ xfburn_progress_dialog_set_progress_bar_fraction (XfburnProgressDialog * dialog,
   if (fraction >= 1.0) {
     fraction = 1.0;
     switch (priv->status) {
+    case XFBURN_PROGRESS_DIALOG_STATUS_STOPPING:
+      text = g_strdup (_("Aborted"));
+      break;
     case XFBURN_PROGRESS_DIALOG_STATUS_RUNNING:
       text = g_strdup ("100%");
       break;
+    case XFBURN_PROGRESS_DIALOG_STATUS_META_DONE:
+      g_warning ("Invalid progress dialog state");
+      break;
     case XFBURN_PROGRESS_DIALOG_STATUS_FAILED:
       text = g_strdup (_("Failed"));
       break;
@@ -536,7 +608,11 @@ xfburn_progress_dialog_set_status (XfburnProgressDialog * dialog, XfburnProgress
 
   priv->status = status;
 
-  if (status != XFBURN_PROGRESS_DIALOG_STATUS_RUNNING) {
+  if (status == XFBURN_PROGRESS_DIALOG_STATUS_STOPPING) {
+    gdk_threads_enter ();
+    set_action_text (dialog, status, _("Aborting..."));
+    gdk_threads_leave ();
+  } else if (status != XFBURN_PROGRESS_DIALOG_STATUS_RUNNING) {
     gdk_threads_enter ();
     gtk_widget_set_sensitive (priv->button_stop, FALSE);
     gtk_widget_set_sensitive (priv->button_close, TRUE);
@@ -549,9 +625,17 @@ xfburn_progress_dialog_set_status (XfburnProgressDialog * dialog, XfburnProgress
 void
 xfburn_progress_dialog_set_status_with_text (XfburnProgressDialog * dialog, XfburnProgressDialogStatus status, const gchar * text)
 {
+  XfburnProgressDialogPrivate *priv = XFBURN_PROGRESS_DIALOG_GET_PRIVATE (dialog);
+
   xfburn_progress_dialog_set_status (dialog, status);
+
   gdk_threads_enter ();
   set_action_text (dialog, status, text);
+  if (status > XFBURN_PROGRESS_DIALOG_STATUS_META_DONE) {
+    g_signal_emit (G_OBJECT (dialog), signals[BURNING_DONE], 0);
+    if (status == XFBURN_PROGRESS_DIALOG_STATUS_COMPLETED && priv->quit)
+      g_idle_add ((GSourceFunc) gtk_main_quit, NULL );
+  }
   gdk_threads_leave ();
 }
 
@@ -565,7 +649,7 @@ xfburn_progress_dialog_burning_failed (XfburnProgressDialog * dialog, const gcha
   xfburn_progress_dialog_set_status_with_text (dialog, XFBURN_PROGRESS_DIALOG_STATUS_FAILED, _("Failure"));
 
   gdk_threads_enter ();
-  xfce_err (msg_error);
+  xfce_dialog_show_error (NULL, NULL, "%s", msg_error);
   gdk_threads_leave ();
 }
 
