@@ -1,4 +1,3 @@
-/* $Id: xfburn-transcoder-gst.c 6351 2008-12-21 03:09:24Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (dmohr@mcbf.net)
@@ -37,7 +36,6 @@
 #include <errno.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
 
 #include <libburn.h>
 
@@ -49,6 +47,8 @@
 #include "xfburn-settings.h"
 
 #include "xfburn-transcoder-gst.h"
+#include "xfburn-audio-track.h"
+#include "xfburn-audio-track-gst.h"
 
 
 /* 
@@ -74,14 +74,13 @@ static void delete_pipeline (XfburnTranscoderGst *trans);
 static void recreate_pipeline (XfburnTranscoderGst *trans);
 static const gchar * get_name (XfburnTranscoder *trans);
 static const gchar * get_description (XfburnTranscoder *trans);
-static XfburnAudioTrack * get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error);
+static gboolean get_audio_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static struct burn_track * create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static gboolean prepare (XfburnTranscoder *trans, GError **error);
 static gboolean transcode_next_track (XfburnTranscoderGst *trans, GError **error);
 static void finish (XfburnTranscoder *trans);
-static gboolean free_burning_resources (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static gboolean is_initialized (XfburnTranscoder *trans, GError **error);
 
@@ -111,11 +110,12 @@ typedef enum {
 
 typedef struct {
   GstElement *pipeline;
-  GstElement *source, *decoder, *conv, *sink;
+  GstElement *source, *decoder, *resample, *conv, *sink;
 
   XfburnTranscoderGstState state;
-  GCond *gst_cond;
-  GMutex *gst_mutex;
+  GCond gst_cond;
+  GMutex gst_mutex;
+  gboolean gst_done;
   gboolean is_audio;
   gint64 duration;
 
@@ -127,15 +127,9 @@ typedef struct {
 } XfburnTranscoderGstPrivate;
 
 
-typedef struct {
-  int fd_in;
-  off_t size;
-} XfburnAudioTrackGst;
-
-
 /* constants */
 
-#define SIGNAL_WAIT_TIMEOUT_MICROS 1500000
+#define SIGNAL_WAIT_TIMEOUT_MS 1500
 
 #define SIGNAL_SEND_ITERATIONS 10
 /* SIGNAL_SEND_TIMEOUT_MICROS is the total time,
@@ -160,10 +154,10 @@ static const gchar *errormsg_libburn_setup = "An error occurred while setting th
 static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
-GtkType
-xfburn_transcoder_gst_get_type ()
+GType
+xfburn_transcoder_gst_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -220,12 +214,12 @@ xfburn_transcoder_gst_init (XfburnTranscoderGst * obj)
 
   /* the condition is used to signal that
    * gst has returned information */
-  priv->gst_cond = g_cond_new ();
+  g_cond_init (&priv->gst_cond);
 
   /* if the mutex is locked, then we're not currently seeking
    * information from gst */
-  priv->gst_mutex = g_mutex_new ();
-  g_mutex_lock (priv->gst_mutex);
+  g_mutex_init (&priv->gst_mutex);
+  g_mutex_lock (&priv->gst_mutex);
 }
 
 static void
@@ -249,7 +243,7 @@ transcoder_interface_init (XfburnTranscoderInterface *iface, gpointer iface_data
   iface->is_initialized = is_initialized;
   iface->get_audio_track = get_audio_track;
   iface->create_burn_track = create_burn_track;
-  iface->free_burning_resources = free_burning_resources;
+  /* free_burning_resources is not needed */
   iface->finish = finish;
   iface->prepare = prepare;
 }
@@ -263,7 +257,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 {
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
 
-  GstElement *pipeline, *source, *decoder, *conv, *sink;
+  GstElement *pipeline, *source, *decoder, *resample, *conv, *sink;
 #if DEBUG_GST > 0 && DEBUG > 0
   GstElement *id;
 #endif
@@ -276,6 +270,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 
   priv->source  = source   = gst_element_factory_make ("filesrc",       "file-source");
   priv->decoder = decoder  = gst_element_factory_make ("decodebin",     "decoder");
+  priv->resample= resample = gst_element_factory_make ("audioresample", "resampler");
   priv->conv    = conv     = gst_element_factory_make ("audioconvert",  "converter");
 #if DEBUG_GST > 0 && DEBUG > 0
                   id       = gst_element_factory_make ("identity",      "debugging-identity");
@@ -284,9 +279,10 @@ create_pipeline (XfburnTranscoderGst *trans)
   //priv->sink    = sink     = gst_element_factory_make ("fakesink",        "audio-output");
   //DBG ("\npipeline = %p\nsource = %p\ndecoder = %p\nconv = %p\nsink = %p", pipeline, source, decoder, conv, sink);
 
-  if (!pipeline || !source || !decoder || !conv || !sink) {
+  if (!pipeline || !source || !decoder || !resample || !conv || !sink) {
     g_warning ("A pipeline element could not be created");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
+		    "%s",
                  _(errormsg_gst_setup));
     return;
   }
@@ -295,6 +291,7 @@ create_pipeline (XfburnTranscoderGst *trans)
   if (!id) {
     g_warning ("The debug identity element could not be created");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
+		    "%s",
                  _(errormsg_gst_setup));
     return;
   }
@@ -307,12 +304,13 @@ create_pipeline (XfburnTranscoderGst *trans)
   gst_object_unref (bus);
 
   gst_bin_add_many (GST_BIN (pipeline),
-                    source, decoder, conv, sink, NULL);
+                    source, decoder, resample, conv, sink, NULL);
 #if DEBUG_GST > 0 && DEBUG > 0
   gst_bin_add (GST_BIN (pipeline), id);
 #endif
 
   gst_element_link (source, decoder);
+  gst_element_link (resample, conv);
 
   /* setup caps for raw pcm data */
   caps = gst_caps_new_simple ("audio/x-raw-int",
@@ -331,6 +329,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 #endif
     g_warning ("Could not setup filtered gstreamer link");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
+		    "%s",
                  _(errormsg_gst_setup));
     gst_caps_unref (caps);
     return;
@@ -405,10 +404,12 @@ signal_identification_done (XfburnTranscoderGst *trans, const char *dbg_res)
   DBG ("Trying to lock mutex (%s)", dbg_res);
 #endif
 
+  priv->gst_done = TRUE;
+
   /* There is no g_mutex_lock_timed, so emulate it with a loop.
     * I have never seen this getting hung here, but one never knows! */
   for (i=0; i<SIGNAL_SEND_ITERATIONS; i++) {
-    if (g_mutex_trylock (priv->gst_mutex))
+    if (g_mutex_trylock (&priv->gst_mutex))
       break;
     g_usleep (SIGNAL_SEND_TIMEOUT_MICROS / SIGNAL_SEND_ITERATIONS);
     g_thread_yield ();
@@ -422,8 +423,8 @@ signal_identification_done (XfburnTranscoderGst *trans, const char *dbg_res)
     }
   }
 
-  g_cond_signal (priv->gst_cond);
-  g_mutex_unlock (priv->gst_mutex);
+  g_cond_signal (&priv->gst_cond);
+  g_mutex_unlock (&priv->gst_mutex);
 
 #if DEBUG_GST > 0
  #if DEBUG > 0
@@ -585,7 +586,7 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
           if (strcmp (GST_OBJECT_NAME (GST_MESSAGE_SRC (msg)), "decoder") != 0)
             break;
           
-          if (!g_mutex_trylock (priv->gst_mutex)) {
+          if (!g_mutex_trylock (&priv->gst_mutex)) {
             g_critical ("Lock held by another thread, can't signal transcoding start!");
             break;
           } else {
@@ -594,8 +595,9 @@ bus_call (GstBus *bus, GstMessage *msg, gpointer data)
 #endif
           }
 
-          g_cond_signal (priv->gst_cond);
-          g_mutex_unlock (priv->gst_mutex);
+          priv->gst_done = TRUE;
+          g_cond_signal (&priv->gst_cond);
+          g_mutex_unlock (&priv->gst_mutex);
           break;
       } /* switch of priv->state */
 
@@ -659,7 +661,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
   GstCaps *caps;
   GstStructure *str;
   GstPad *audiopad;
-  GstElement *audio = (GstElement *) priv->conv;
+  GstElement *audio = (GstElement *) priv->resample;
 
   // only link once
   audiopad = gst_element_get_static_pad (audio, "sink");
@@ -683,13 +685,14 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
 
     gchar *error_msg = "File content has a decoder but is not audio.";
 
-    DBG (error_msg);
+    DBG ("%s", error_msg);
     
     gst_caps_unref (caps);
     gst_object_unref (audiopad);
 
     priv->is_audio = FALSE;
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_NO_AUDIO,
+		    "%s",
                  _(error_msg));
     
     msg_struct = gst_structure_new ("no-audio-content", NULL);
@@ -757,58 +760,54 @@ cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data)
 #endif
 
 
-static XfburnAudioTrack *
-get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
+static gboolean
+get_audio_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
   XfburnTranscoderGst *tgst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (tgst);
 
-  XfburnAudioTrack *atrack;
   XfburnAudioTrackGst *gtrack;
-  GTimeVal tv;
+  gint64 end_time;
   off_t size;
 
   priv->is_audio = FALSE;
 #if DEBUG_GST > 0
-  DBG ("Querying GST about %s", fn);
+  DBG ("Querying GST about %s", atrack->inputfile);
 #endif
 
   priv->state = XFBURN_TRANSCODER_GST_STATE_IDENTIFYING;
-  g_object_set (G_OBJECT (priv->source), "location", fn, NULL);
+  g_object_set (G_OBJECT (priv->source), "location", atrack->inputfile, NULL);
   if (gst_element_set_state (priv->pipeline, GST_STATE_PAUSED) == GST_STATE_CHANGE_FAILURE) {
 #if DEBUG_GST > 0
     g_message ("Supposedly failed to change gstreamer state, ignoring it as usually it does it anyways.");
 #endif
   }
 
-  g_get_current_time (&tv);
-  g_time_val_add (&tv, SIGNAL_WAIT_TIMEOUT_MICROS);
+  end_time = g_get_monotonic_time () + SIGNAL_WAIT_TIMEOUT_MS * G_TIME_SPAN_MILLISECOND;
 #if DEBUG_GST > 0
   DBG ("Now waiting for identification result");
 #endif
-  if (!g_cond_timed_wait (priv->gst_cond, priv->gst_mutex, &tv)) {
-    DBG ("gst identification timed out");
-    recreate_pipeline (tgst);
-    g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_GST_TIMEOUT,
-                 _("Gstreamer did not like this file (detection timed out)"));
-    return NULL;
-  }
+  while (!priv->gst_done)
+    if (!g_cond_wait_until (&priv->gst_cond, &priv->gst_mutex, end_time)) {
+      DBG ("gst identification timed out");
+      recreate_pipeline (tgst);
+      g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_GST_TIMEOUT,
+                   _("Gstreamer did not like this file (detection timed out)"));
+      return FALSE;
+    }
+  priv->gst_done = FALSE;
 #if DEBUG_GST > 0
   DBG ("Got an identification result ");
 #endif
 
   if (!priv->is_audio) {
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_NOT_AUDIO_FORMAT,
-                 _("%s\n\nis not an audio file:\n\n%s"), fn, priv->error->message);
+                 _("%s\n\nis not an audio file:\n\n%s"), atrack->inputfile, priv->error->message);
     g_error_free (priv->error);
     priv->error = NULL;
-    return NULL;
+    return FALSE;
   }
 
-  atrack = g_new0 (XfburnAudioTrack, 1);
-  /* FIXME: when do we free inputfile?? */
-  atrack->inputfile = g_strdup (fn);
-  atrack->pos = -1;
   atrack->length = priv->duration / 1000000000;
 
   size = (off_t) floorf (priv->duration * (PCM_BYTES_PER_SECS / (float) 1000000000));
@@ -819,14 +818,15 @@ get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
 
   gtrack = g_new0 (XfburnAudioTrackGst, 1);
   atrack->data = (gpointer) gtrack;
+  atrack->type = XFBURN_TYPE_AUDIO_TRACK_GST;
 
   gtrack->size = size;
 
-  return atrack;
+  return TRUE;
 }
 
 
-
+/* initialize the XfburnAudioTrack */
 static struct burn_track *
 create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
@@ -840,7 +840,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
   struct burn_source *src_fifo;
 
   if (pipe (pipe_fd) != 0) {
-    g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_PIPE, g_strerror (errno));
+    g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_PIPE, "%s", g_strerror (errno));
     return NULL;
   }
 
@@ -852,6 +852,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
   if (atrack->src == NULL) {
     g_warning ("Could not create burn_source from %s.", atrack->inputfile);
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_BURN_SOURCE,
+		 "%s",
                  _(errormsg_libburn_setup));
     XFBURN_AUDIO_TRACK_DELETE_DATA (atrack);
     atrack->fd = -1;
@@ -871,6 +872,7 @@ create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **e
   if (burn_track_set_source (track, atrack->src) != BURN_SOURCE_OK) {
     g_warning ("Could not add source to track %s.", atrack->inputfile);
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_BURN_SOURCE,
+		 "%s",
                  _(errormsg_libburn_setup));
     XFBURN_AUDIO_TRACK_DELETE_DATA (atrack);
     burn_source_free (atrack->src);
@@ -902,7 +904,7 @@ prepare (XfburnTranscoder *trans, GError **error)
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
   gboolean ret;
-  GTimeVal tv;
+  gint64 end_time;
 
   priv->tracks = g_slist_reverse (priv->tracks);
 
@@ -910,14 +912,14 @@ prepare (XfburnTranscoder *trans, GError **error)
   ret = transcode_next_track (gst, error);
 
   //DBG ("Waiting for start signal");
-  g_get_current_time (&tv);
-  g_time_val_add (&tv, SIGNAL_WAIT_TIMEOUT_MICROS);
-  if (!g_cond_timed_wait (priv->gst_cond, priv->gst_mutex, &tv)) {
-    recreate_pipeline (gst);
-    g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_GST_TIMEOUT,
-                 _("Gstreamer did not want to start transcoding (timed out)"));
-    return FALSE;
-  }
+  end_time = g_get_monotonic_time () + SIGNAL_WAIT_TIMEOUT_MS * G_TIME_SPAN_MILLISECOND;
+  while (!priv->gst_done)
+    if (!g_cond_wait_until (&priv->gst_cond, &priv->gst_mutex, end_time)) {
+      recreate_pipeline (gst);
+      g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_GST_TIMEOUT,
+                  _("Gstreamer did not want to start transcoding (timed out)"));
+      return FALSE;
+    }
   //DBG ("Got the start signal");
 
   priv->state = XFBURN_TRANSCODER_GST_STATE_TRANSCODING;
@@ -966,9 +968,11 @@ finish (XfburnTranscoder *trans)
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
 
+  /*
   GstState state;
   GstClock *clock;
   GstClockTime tv;
+  */
 
 #if DEBUG_GST > 0
   DBG ("Done transcoding");
@@ -977,6 +981,11 @@ finish (XfburnTranscoder *trans)
 
   priv->curr_track = NULL;
 
+  /*
+   * gstreamer doesn't even want to work with us again after getting back into
+   * the ready state. Lame. So we just recreate the pipeline.
+   * Which doesn't help either. Oh Well.
+   * FIXME: how to get gstreamer to accept state changes again after an aborted burn run?
   clock = gst_element_get_clock (priv->pipeline);
   tv = gst_clock_get_time (clock);
   g_object_unref (clock);
@@ -993,22 +1002,8 @@ finish (XfburnTranscoder *trans)
     DBG ("Could not make pipeline ready, recreating it");
     recreate_pipeline (gst);
   }
-}
-
-static gboolean
-free_burning_resources (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
-{
-  /*
-  XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
-  XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
   */
-  
-  XfburnAudioTrackGst *gtrack = XFBURN_AUDIO_TRACK_GET_GST (atrack);
-  
-  g_free (gtrack);
-  atrack->data = NULL;
-
-  return TRUE;
+  recreate_pipeline (gst);
 }
 
 
@@ -1034,7 +1029,7 @@ is_initialized (XfburnTranscoder *trans, GError **error)
 /*        */
 
 GObject *
-xfburn_transcoder_gst_new ()
+xfburn_transcoder_gst_new (void)
 {
   return g_object_new (XFBURN_TYPE_TRANSCODER_GST, NULL);
 }
