@@ -1,4 +1,3 @@
-/* $Id: xfburn-utils.h 7677 2009-07-05 00:55:15Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -28,17 +27,23 @@
 
 #include "xfburn-global.h"
 
+/*
+#define XFBURN_GDK_ENTER() { DBG("gdk-thread-enter"); gdk_threads_enter(); }
+#define XFBURN_GDK_LEAVE() { DBG("gdk-thread-leave"); gdk_threads_leave(); }
+*/
+
 void xfburn_busy_cursor (GtkWidget *);
 void xfburn_default_cursor (GtkWidget *);
 
 gchar *xfburn_humanreadable_filesize (guint64);
 guint64 xfburn_calc_dirsize (const gchar *);
+GSList * xfburn_make_abosulet_file_list (gint count, gchar *filenames[]);
 
 void xfburn_browse_for_file (GtkEntry *entry, GtkWindow *parent);
 
 gboolean xfburn_ask_yes_no (GtkMessageType type, const gchar *primary_text, const gchar *secondary_text);
 
-void xfburn_capture_libburn_messages ();
-void xfburn_console_libburn_messages ();
+void xfburn_capture_libburn_messages (void);
+void xfburn_console_libburn_messages (void);
 
 #endif
